<?php
// Oturum başlatma ve kontrolü
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    http_response_code(401);
    echo json_encode(['success' => false, 'message' => 'Yetkisiz erişim']);
    exit;
}

// Yalnızca POST isteklerine izin ver
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['success' => false, 'message' => 'Geçersiz istek metodu']);
    exit;
}

// Gereken dosyaları dahil et
require_once '../config/database.php';
require_once '../classes/Customer.php';

// Kullanıcı bilgilerini al
$userId = $_SESSION['user_id'];
$companyId = $_SESSION['company_id'];

// Gelen form verilerini al
$firstName = trim($_POST['first_name'] ?? '');
$lastName = trim($_POST['last_name'] ?? '');
$phone = trim($_POST['phone'] ?? '');
$identityNumber = trim($_POST['identity_number'] ?? '');
$email = trim($_POST['email'] ?? '');
$address = trim($_POST['address'] ?? '');
$city = trim($_POST['city'] ?? '');

// Temel veri doğrulama
if (empty($firstName) || empty($lastName) || empty($phone)) {
    echo json_encode(['success' => false, 'message' => 'Ad, soyad ve telefon alanları zorunludur']);
    exit;
}

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Müşteri nesnesi oluştur
    $customer = new Customer($conn);

    // Müşteri bilgilerini ayarla
    $customer->company_id = $companyId;
    $customer->first_name = $firstName;
    $customer->last_name = $lastName;
    $customer->phone = $phone;
    $customer->identity_number = $identityNumber;
    $customer->email = $email;
    $customer->address = $address;
    $customer->city = $city;
    $customer->status = 'active';

    // Müşteriyi oluştur
    if ($customer->create()) {
        // Başarılı yanıt döndür
        echo json_encode([
            'success' => true,
            'customer_id' => $customer->id,
            'customer_name' => $firstName . ' ' . $lastName . ' - ' . $phone
        ]);
    } else {
        // Hata yanıtı döndür
        echo json_encode(['success' => false, 'message' => 'Müşteri oluşturulurken bir hata oluştu']);
    }
} catch (Exception $e) {
    // Hata durumunda yanıt döndür
    echo json_encode(['success' => false, 'message' => 'Sistem hatası: ' . $e->getMessage()]);
}
?>