<?php
// Oturum başlatma ve kontrolü
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    http_response_code(401);
    echo json_encode(['success' => false, 'message' => 'Yetkisiz erişim']);
    exit;
}

// Yalnızca GET isteklerine izin ver
if ($_SERVER['REQUEST_METHOD'] !== 'GET') {
    http_response_code(405);
    echo json_encode(['success' => false, 'message' => 'Geçersiz istek metodu']);
    exit;
}

// Gereken dosyaları dahil et
require_once '../config/database.php';
require_once '../classes/Vehicle.php';

// Gerekli parametreler
$customerId = isset($_GET['customer_id']) ? (int)$_GET['customer_id'] : 0;

// Müşteri ID kontrolü
if ($customerId <= 0) {
    echo json_encode(['success' => false, 'message' => 'Geçersiz müşteri ID']);
    exit;
}

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Araç nesnesi oluştur
    $vehicle = new Vehicle($conn);

    // Müşteriye ait araçları getir
    $vehicles = $vehicle->getVehiclesByCustomer($customerId);

    // Sonuçları döndür
    echo json_encode([
        'success' => true,
        'vehicles' => $vehicles,
        'count' => count($vehicles)
    ]);

} catch (Exception $e) {
    // Hata durumunda
    http_response_code(500);
    echo json_encode(['success' => false, 'message' => 'Sistem hatası: ' . $e->getMessage()]);
}
?>