<?php
/**
 * Motor Testi işlemleri sınıfı
 */
class MotorTest {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "motor_testi";

    // Motor Testi özellikleri
    public $id;
    public $expertise_id;
    public $vehicle_id;
    public $atesleme_buji_bobin;
    public $hava_debi_metre;
    public $e_kientrik_okuyucu;
    public $gaz_kelebegi;
    public $motor_elektrik_tesisati;
    public $krank_arka_kece;
    public $airbeg;
    public $fren_hidroligi;
    public $antifriz;
    public $otomitik_sanziman_yagi;
    public $co2_testi;
    public $aku;
    public $oksijen_sensoru;
    public $motor_yagi;
    public $lastik_basinc_okuyucu;
    public $sogutma_fani;
    public $tum_kayislar;
    public $krank_on_kece;
    public $start_stop;
    public $hava_filtre_kutu;
    public $kurbirator_kapak_conta;
    public $klima_gazi;
    public $direksiyon_yagi_ve_pompasi;
    public $radyator_klima_interkul;
    public $turbo;
    public $sogutma_suyu_hortumu_sizdirmazlik;
    public $motor_yagi_sizdirmazlik;
    public $motor_testi_notlari;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni motor testi kaydı oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (expertise_id, vehicle_id, atesleme_buji_bobin, hava_debi_metre, e_kientrik_okuyucu,
                   gaz_kelebegi, motor_elektrik_tesisati, krank_arka_kece, airbeg, fren_hidroligi,
                   antifriz, otomitik_sanziman_yagi, co2_testi, aku, oksijen_sensoru,
                   motor_yagi, lastik_basinc_okuyucu, sogutma_fani, tum_kayislar, krank_on_kece,
                   start_stop, hava_filtre_kutu, kurbirator_kapak_conta, klima_gazi, direksiyon_yagi_ve_pompasi,
                   radyator_klima_interkul, turbo, sogutma_suyu_hortumu_sizdirmazlik, motor_yagi_sizdirmazlik,
                   motor_testi_notlari, created_at)
                  VALUES
                  (:expertise_id, :vehicle_id, :atesleme_buji_bobin, :hava_debi_metre, :e_kientrik_okuyucu,
                   :gaz_kelebegi, :motor_elektrik_tesisati, :krank_arka_kece, :airbeg, :fren_hidroligi,
                   :antifriz, :otomitik_sanziman_yagi, :co2_testi, :aku, :oksijen_sensoru,
                   :motor_yagi, :lastik_basinc_okuyucu, :sogutma_fani, :tum_kayislar, :krank_on_kece,
                   :start_stop, :hava_filtre_kutu, :kurbirator_kapak_conta, :klima_gazi, :direksiyon_yagi_ve_pompasi,
                   :radyator_klima_interkul, :turbo, :sogutma_suyu_hortumu_sizdirmazlik, :motor_yagi_sizdirmazlik,
                   :motor_testi_notlari, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->motor_testi_notlari = htmlspecialchars(strip_tags($this->motor_testi_notlari));

        // Parametreleri bağlama
        $stmt->bindParam(':expertise_id', $this->expertise_id);
        $stmt->bindParam(':vehicle_id', $this->vehicle_id);
        $stmt->bindParam(':atesleme_buji_bobin', $this->atesleme_buji_bobin);
        $stmt->bindParam(':hava_debi_metre', $this->hava_debi_metre);
        $stmt->bindParam(':e_kientrik_okuyucu', $this->e_kientrik_okuyucu);
        $stmt->bindParam(':gaz_kelebegi', $this->gaz_kelebegi);
        $stmt->bindParam(':motor_elektrik_tesisati', $this->motor_elektrik_tesisati);
        $stmt->bindParam(':krank_arka_kece', $this->krank_arka_kece);
        $stmt->bindParam(':airbeg', $this->airbeg);
        $stmt->bindParam(':fren_hidroligi', $this->fren_hidroligi);
        $stmt->bindParam(':antifriz', $this->antifriz);
        $stmt->bindParam(':otomitik_sanziman_yagi', $this->otomitik_sanziman_yagi);
        $stmt->bindParam(':co2_testi', $this->co2_testi);
        $stmt->bindParam(':aku', $this->aku);
        $stmt->bindParam(':oksijen_sensoru', $this->oksijen_sensoru);
        $stmt->bindParam(':motor_yagi', $this->motor_yagi);
        $stmt->bindParam(':lastik_basinc_okuyucu', $this->lastik_basinc_okuyucu);
        $stmt->bindParam(':sogutma_fani', $this->sogutma_fani);
        $stmt->bindParam(':tum_kayislar', $this->tum_kayislar);
        $stmt->bindParam(':krank_on_kece', $this->krank_on_kece);
        $stmt->bindParam(':start_stop', $this->start_stop);
        $stmt->bindParam(':hava_filtre_kutu', $this->hava_filtre_kutu);
        $stmt->bindParam(':kurbirator_kapak_conta', $this->kurbirator_kapak_conta);
        $stmt->bindParam(':klima_gazi', $this->klima_gazi);
        $stmt->bindParam(':direksiyon_yagi_ve_pompasi', $this->direksiyon_yagi_ve_pompasi);
        $stmt->bindParam(':radyator_klima_interkul', $this->radyator_klima_interkul);
        $stmt->bindParam(':turbo', $this->turbo);
        $stmt->bindParam(':sogutma_suyu_hortumu_sizdirmazlik', $this->sogutma_suyu_hortumu_sizdirmazlik);
        $stmt->bindParam(':motor_yagi_sizdirmazlik', $this->motor_yagi_sizdirmazlik);
        $stmt->bindParam(':motor_testi_notlari', $this->motor_testi_notlari);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Motor testini ID ile getirme
     *
     * @param int $expertise_id Ekspertiz ID
     * @return array|boolean Test verileri veya başarısız ise false
     */
    public function readByExpertiseId($expertise_id) {
        // SQL sorgusu
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE expertise_id = :expertise_id 
                  LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(':expertise_id', $expertise_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }

        return false;
    }

    /**
     * Motor testini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET atesleme_buji_bobin = :atesleme_buji_bobin,
                      hava_debi_metre = :hava_debi_metre,
                      e_kientrik_okuyucu = :e_kientrik_okuyucu,
                      gaz_kelebegi = :gaz_kelebegi,
                      motor_elektrik_tesisati = :motor_elektrik_tesisati,
                      krank_arka_kece = :krank_arka_kece,
                      airbeg = :airbeg,
                      fren_hidroligi = :fren_hidroligi,
                      antifriz = :antifriz,
                      otomitik_sanziman_yagi = :otomitik_sanziman_yagi,
                      co2_testi = :co2_testi,
                      aku = :aku,
                      oksijen_sensoru = :oksijen_sensoru,
                      motor_yagi = :motor_yagi,
                      lastik_basinc_okuyucu = :lastik_basinc_okuyucu,
                      sogutma_fani = :sogutma_fani,
                      tum_kayislar = :tum_kayislar,
                      krank_on_kece = :krank_on_kece,
                      start_stop = :start_stop,
                      hava_filtre_kutu = :hava_filtre_kutu,
                      kurbirator_kapak_conta = :kurbirator_kapak_conta,
                      klima_gazi = :klima_gazi,
                      direksiyon_yagi_ve_pompasi = :direksiyon_yagi_ve_pompasi,
                      radyator_klima_interkul = :radyator_klima_interkul,
                      turbo = :turbo,
                      sogutma_suyu_hortumu_sizdirmazlik = :sogutma_suyu_hortumu_sizdirmazlik,
                      motor_yagi_sizdirmazlik = :motor_yagi_sizdirmazlik,
                      motor_testi_notlari = :motor_testi_notlari,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->motor_testi_notlari = htmlspecialchars(strip_tags($this->motor_testi_notlari));

        // Parametreleri bağlama
        $stmt->bindParam(':id', $this->id);
        $stmt->bindParam(':atesleme_buji_bobin', $this->atesleme_buji_bobin);
        $stmt->bindParam(':hava_debi_metre', $this->hava_debi_metre);
        $stmt->bindParam(':e_kientrik_okuyucu', $this->e_kientrik_okuyucu);
        $stmt->bindParam(':gaz_kelebegi', $this->gaz_kelebegi);
        $stmt->bindParam(':motor_elektrik_tesisati', $this->motor_elektrik_tesisati);
        $stmt->bindParam(':krank_arka_kece', $this->krank_arka_kece);
        $stmt->bindParam(':airbeg', $this->airbeg);
        $stmt->bindParam(':fren_hidroligi', $this->fren_hidroligi);
        $stmt->bindParam(':antifriz', $this->antifriz);
        $stmt->bindParam(':otomitik_sanziman_yagi', $this->otomitik_sanziman_yagi);
        $stmt->bindParam(':co2_testi', $this->co2_testi);
        $stmt->bindParam(':aku', $this->aku);
        $stmt->bindParam(':oksijen_sensoru', $this->oksijen_sensoru);
        $stmt->bindParam(':motor_yagi', $this->motor_yagi);
        $stmt->bindParam(':lastik_basinc_okuyucu', $this->lastik_basinc_okuyucu);
        $stmt->bindParam(':sogutma_fani', $this->sogutma_fani);
        $stmt->bindParam(':tum_kayislar', $this->tum_kayislar);
        $stmt->bindParam(':krank_on_kece', $this->krank_on_kece);
        $stmt->bindParam(':start_stop', $this->start_stop);
        $stmt->bindParam(':hava_filtre_kutu', $this->hava_filtre_kutu);
        $stmt->bindParam(':kurbirator_kapak_conta', $this->kurbirator_kapak_conta);
        $stmt->bindParam(':klima_gazi', $this->klima_gazi);
        $stmt->bindParam(':direksiyon_yagi_ve_pompasi', $this->direksiyon_yagi_ve_pompasi);
        $stmt->bindParam(':radyator_klima_interkul', $this->radyator_klima_interkul);
        $stmt->bindParam(':turbo', $this->turbo);
        $stmt->bindParam(':sogutma_suyu_hortumu_sizdirmazlik', $this->sogutma_suyu_hortumu_sizdirmazlik);
        $stmt->bindParam(':motor_yagi_sizdirmazlik', $this->motor_yagi_sizdirmazlik);
        $stmt->bindParam(':motor_testi_notlari', $this->motor_testi_notlari);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz ve araç ID'sine göre motor testi oluşturma veya güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function saveOrUpdate() {
        // Önce kayıt mevcut mu kontrol et
        $query = "SELECT id FROM " . $this->table_name . " 
                  WHERE expertise_id = :expertise_id 
                  LIMIT 1";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':expertise_id', $this->expertise_id);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            // Kayıt varsa güncelle
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            $this->id = $row['id'];
            return $this->update();
        } else {
            // Kayıt yoksa oluştur
            return $this->create();
        }
    }

    /**
     * Motor testi silme
     *
     * @param int $id Test ID
     * @return boolean İşlem başarılı mı
     */
    public function delete($id) {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }
}