<?php
/**
 * Veritabanı bağlantı sınıfı
 * SaaS yapısına uygun tasarlanmıştır
 */
class Database {
    // Veritabanı parametreleri
    private $host = "localhost";
    private $db_name = "iharseksper_exper";
    private $username = "iharseksper_exper";
    private $password = "ARISTOTALES159357852/*"; // Üretim ortamında güvenli bir şifre kullanılmalıdır
    private $conn;

    /**
     * Veritabanı bağlantısını oluşturma
     *
     * @return PDO
     */
    public function getConnection() {
        $this->conn = null;

        try {
            $this->conn = new PDO(
                "mysql:host=" . $this->host . ";dbname=" . $this->db_name,
                $this->username,
                $this->password,
                [
                    PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
                    PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
                    PDO::ATTR_EMULATE_PREPARES => false,
                    PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8mb4 COLLATE utf8mb4_unicode_ci"
                ]
            );
        } catch(PDOException $e) {
            // Bağlantı hatası
            error_log("Veritabanı bağlantı hatası: " . $e->getMessage());
            throw new Exception("Veritabanına bağlanırken bir hata oluştu.");
        }

        return $this->conn;
    }

    /**
     * SaaS yapısı için şirket/kullanıcı bazlı veritabanı bağlantısı
     *
     * @param int $company_id
     * @return PDO
     */
    public function getCompanyConnection($company_id) {
        // Çoklu veritabanı yapısı için
        // Şirket ID'sine göre farklı veritabanlarına bağlanma
        // Ya da aynı veritabanında şirket ID'si ile filtreleme yapma

        // Bu örnekte aynı veritabanı kullanılıyor, gerçek uygulamada değiştirilebilir
        return $this->getConnection();
    }

    /**
     * Veritabanı tablosunda arama yapma
     *
     * @param string $table Tablo adı
     * @param array $conditions Koşullar (örnek: ['column' => 'value'])
     * @param string $fields Alınacak alanlar (varsayılan: *)
     * @return array
     */
    public function find($table, $conditions = [], $fields = '*') {
        $sql = "SELECT {$fields} FROM {$table}";

        if (!empty($conditions)) {
            $sql .= " WHERE ";
            $params = [];
            $where = [];

            foreach ($conditions as $key => $value) {
                if (is_null($value)) {
                    $where[] = "{$key} IS NULL";
                } else {
                    $where[] = "{$key} = :{$key}";
                    $params[":{$key}"] = $value;
                }
            }

            $sql .= implode(' AND ', $where);
        }

        $stmt = $this->conn->prepare($sql);

        if (!empty($params)) {
            foreach ($params as $key => $value) {
                $stmt->bindValue($key, $value);
            }
        }

        $stmt->execute();
        return $stmt->fetchAll();
    }

    /**
     * Veritabanı tablosuna veri ekleme
     *
     * @param string $table Tablo adı
     * @param array $data Eklenecek veriler (örnek: ['column' => 'value'])
     * @return int Son eklenen kaydın ID'si
     */
    public function insert($table, $data) {
        $columns = implode(', ', array_keys($data));
        $placeholders = ':' . implode(', :', array_keys($data));

        $sql = "INSERT INTO {$table} ({$columns}) VALUES ({$placeholders})";
        $stmt = $this->conn->prepare($sql);

        foreach ($data as $key => $value) {
            $stmt->bindValue(":{$key}", $value);
        }

        $stmt->execute();
        return $this->conn->lastInsertId();
    }

    /**
     * Veritabanı tablosundaki veriyi güncelleme
     *
     * @param string $table Tablo adı
     * @param array $data Güncellenecek veriler (örnek: ['column' => 'value'])
     * @param array $conditions Koşullar (örnek: ['id' => 1])
     * @return int Etkilenen satır sayısı
     */
    public function update($table, $data, $conditions) {
        $sets = [];
        $params = [];

        foreach ($data as $key => $value) {
            $sets[] = "{$key} = :{$key}";
            $params[":{$key}"] = $value;
        }

        $sql = "UPDATE {$table} SET " . implode(', ', $sets);

        if (!empty($conditions)) {
            $sql .= " WHERE ";
            $where = [];

            foreach ($conditions as $key => $value) {
                $where[] = "{$key} = :where_{$key}";
                $params[":where_{$key}"] = $value;
            }

            $sql .= implode(' AND ', $where);
        }

        $stmt = $this->conn->prepare($sql);

        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->execute();
        return $stmt->rowCount();
    }

    /**
     * Veritabanı tablosundan veri silme
     *
     * @param string $table Tablo adı
     * @param array $conditions Koşullar (örnek: ['id' => 1])
     * @return int Etkilenen satır sayısı
     */
    public function delete($table, $conditions) {
        $sql = "DELETE FROM {$table}";

        if (!empty($conditions)) {
            $sql .= " WHERE ";
            $params = [];
            $where = [];

            foreach ($conditions as $key => $value) {
                $where[] = "{$key} = :{$key}";
                $params[":{$key}"] = $value;
            }

            $sql .= implode(' AND ', $where);
        }

        $stmt = $this->conn->prepare($sql);

        if (!empty($params)) {
            foreach ($params as $key => $value) {
                $stmt->bindValue($key, $value);
            }
        }

        $stmt->execute();
        return $stmt->rowCount();
    }
}
?>