<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// Tarih formatı ayarları
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
date_default_timezone_set('Europe/Istanbul');

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $user = new User($conn);
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $customer = new Customer($conn);

    // İstatistikleri alma
    $expertiseCount = $expertise->countExpertises($companyId);
    $vehicleCount = $vehicle->countVehicles($companyId);
    $customerCount = $customer->countCustomers($companyId);
    $userCount = $user->countUsersByCompany($companyId);

    // Son eklenen ekspertizleri alma
    $recentExpertises = $expertise->getRecentExpertises($companyId, 5);

    // Bu ayki ekspertiz sayısı
    $currentMonthExpertiseCount = $expertise->countExpertisesByMonth($companyId, date('m'), date('Y'));

    // Geçen ayki ekspertiz sayısı
    $lastMonth = date('m') - 1;
    $lastMonthYear = date('Y');
    if ($lastMonth == 0) {
        $lastMonth = 12;
        $lastMonthYear--;
    }
    $lastMonthExpertiseCount = $expertise->countExpertisesByMonth($companyId, $lastMonth, $lastMonthYear);

    // Artış/azalış oranı
    $expertiseChangeRate = 0;
    if ($lastMonthExpertiseCount > 0) {
        $expertiseChangeRate = (($currentMonthExpertiseCount - $lastMonthExpertiseCount) / $lastMonthExpertiseCount) * 100;
    }

} catch (Exception $e) {
    // Hata durumunda hata mesajını logla
    error_log("Dashboard hata: " . $e->getMessage());
    $errorMessage = "Sistem verileri yüklenirken bir hata oluştu. Lütfen daha sonra tekrar deneyin.";
}

// Aktif sayfa
$activePage = 'dashboard';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gösterge Paneli - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- ApexCharts -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.35.3/dist/apexcharts.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">
   <?php include "includes/style.php"; ?>
</head>
<body>
<!-- Sidebar -->

<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->

    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header">
            <h1 class="page-title">Gösterge Paneli</h1>
            <nav aria-label="breadcrumb">
                <ol class="breadcrumb">
                    <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                    <li class="breadcrumb-item active" aria-current="page">Gösterge Paneli</li>
                </ol>
            </nav>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <!-- Stats Row -->
        <div class="row">
            <div class="col-xl-3 col-md-6">
                <div class="card">
                    <div class="card-body">
                        <div class="stats-card">
                            <div class="stats-icon primary">
                                <i class="fas fa-clipboard-check"></i>
                            </div>
                            <div class="stats-info">
                                <h3><?php echo number_format($expertiseCount); ?></h3>
                                <p>Toplam Ekspertiz</p>
                                <div class="stats-change <?php echo ($expertiseChangeRate >= 0) ? 'up' : 'down'; ?>">
                                    <i class="fas <?php echo ($expertiseChangeRate >= 0) ? 'fa-arrow-up' : 'fa-arrow-down'; ?> me-1"></i>
                                    <?php echo number_format(abs($expertiseChangeRate), 1); ?>% geçen aya göre
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-3 col-md-6">
                <div class="card">
                    <div class="card-body">
                        <div class="stats-card">
                            <div class="stats-icon success">
                                <i class="fas fa-car"></i>
                            </div>
                            <div class="stats-info">
                                <h3><?php echo number_format($vehicleCount); ?></h3>
                                <p>Toplam Araç</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-3 col-md-6">
                <div class="card">
                    <div class="card-body">
                        <div class="stats-card">
                            <div class="stats-icon warning">
                                <i class="fas fa-users"></i>
                            </div>
                            <div class="stats-info">
                                <h3><?php echo number_format($customerCount); ?></h3>
                                <p>Toplam Müşteri</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="col-xl-3 col-md-6">
                <div class="card">
                    <div class="card-body">
                        <div class="stats-card">
                            <div class="stats-icon danger">
                                <i class="fas fa-user"></i>
                            </div>
                            <div class="stats-info">
                                <h3><?php echo number_format($userCount); ?></h3>
                                <p>Toplam Kullanıcı</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Charts Row -->
        <div class="row">
            <div class="col-xl-8">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h5 class="card-title">Ekspertiz İstatistikleri</h5>
                        <div class="dropdown">
                            <button class="btn btn-sm btn-outline-secondary dropdown-toggle" type="button" id="chartDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                                Bu Yıl
                            </button>
                            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="chartDropdown">
                                <li><a class="dropdown-item" href="#">Bu Ay</a></li>
                                <li><a class="dropdown-item" href="#">Bu Yıl</a></li>
                                <li><a class="dropdown-item" href="#">Tüm Zamanlar</a></li>
                            </ul>
                        </div>
                    </div>
                    <div class="card-body">
                        <div id="expertiseChart" class="chart-container"></div>
                    </div>
                </div>
            </div>

            <div class="col-xl-4">
                <div class="card">
                    <div class="card-header">
                        <h5 class="card-title">Ekspertiz Durumları</h5>
                    </div>
                    <div class="card-body">
                        <div id="statusChart" class="chart-container"></div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Recent Expertises Row -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h5 class="card-title">Son Eklenen Ekspertizler</h5>
                        <a href="expertises.php" class="btn btn-sm btn-primary">Tümünü Gör</a>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-hover">
                                <thead>
                                <tr>
                                    <th>Ekspertiz Kodu</th>
                                    <th>Müşteri</th>
                                    <th>Araç</th>
                                    <th>Tarih</th>
                                    <th>Durum</th>
                                    <th>İşlemler</th>
                                </tr>
                                </thead>
                                <tbody>
                                <?php if (!empty($recentExpertises)): ?>
                                    <?php foreach ($recentExpertises as $expertise): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($expertise['expertise_code']); ?></td>
                                            <td>
                                                <div class="table-user">
                                                    <div class="table-avatar">
                                                        <?php echo strtoupper(substr($expertise['customer_name'], 0, 1)); ?>
                                                    </div>
                                                    <span class="table-username"><?php echo htmlspecialchars($expertise['customer_name']); ?></span>
                                                </div>
                                            </td>
                                            <td><?php echo htmlspecialchars($expertise['vehicle_info']); ?></td>
                                            <td><?php echo date('d.m.Y H:i', strtotime($expertise['expertise_date'])); ?></td>
                                            <td>
                                                <?php
                                                $statusClass = '';
                                                switch ($expertise['status']) {
                                                    case 'pending':
                                                        $statusClass = 'pending';
                                                        $statusText = 'Bekliyor';
                                                        break;
                                                    case 'in_progress':
                                                        $statusClass = 'in_progress';
                                                        $statusText = 'Devam Ediyor';
                                                        break;
                                                    case 'completed':
                                                        $statusClass = 'completed';
                                                        $statusText = 'Tamamlandı';
                                                        break;
                                                    case 'cancelled':
                                                        $statusClass = 'cancelled';
                                                        $statusText = 'İptal Edildi';
                                                        break;
                                                    default:
                                                        $statusClass = 'pending';
                                                        $statusText = 'Bekliyor';
                                                }
                                                ?>
                                                <span class="status-badge <?php echo $statusClass; ?>"><?php echo $statusText; ?></span>
                                            </td>
                                            <td>
                                                <div class="d-flex">
                                                    <a href="expertise_view.php?id=<?php echo $expertise['id']; ?>" class="action-button me-1" title="Görüntüle">
                                                        <i class="fas fa-eye"></i>
                                                    </a>
                                                    <a href="expertise_edit.php?id=<?php echo $expertise['id']; ?>" class="action-button me-1" title="Düzenle">
                                                        <i class="fas fa-edit"></i>
                                                    </a>
                                                    <a href="expertise_print.php?id=<?php echo $expertise['id']; ?>" class="action-button" title="Yazdır">
                                                        <i class="fas fa-print"></i>
                                                    </a>
                                                </div>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="6" class="text-center">Henüz ekspertiz kaydı bulunmamaktadır.</td>
                                    </tr>
                                <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Cards Row -->
        <div class="row">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h5 class="card-title">Yapılacaklar</h5>
                        <button class="btn btn-sm btn-outline-primary" data-bs-toggle="modal" data-bs-target="#taskModal">
                            <i class="fas fa-plus me-1"></i> Yeni Ekle
                        </button>
                    </div>
                    <div class="card-body">
                        <ul class="list-group">
                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" value="" id="task1">
                                    <label class="form-check-label" for="task1">
                                        Haftalık raporu hazırla
                                    </label>
                                </div>
                                <span class="badge bg-primary rounded-pill">Bugün</span>
                            </li>
                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" value="" id="task2">
                                    <label class="form-check-label" for="task2">
                                        Yeni müşteri tekliflerini gözden geçir
                                    </label>
                                </div>
                                <span class="badge bg-warning rounded-pill">Yarın</span>
                            </li>
                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" value="" id="task3" checked>
                                    <label class="form-check-label text-decoration-line-through" for="task3">
                                        Ekspertiz raporlarını arşivle
                                    </label>
                                </div>
                                <span class="badge bg-success rounded-pill">Tamamlandı</span>
                            </li>
                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" value="" id="task4">
                                    <label class="form-check-label" for="task4">
                                        Sistem güncellemelerini kontrol et
                                    </label>
                                </div>
                                <span class="badge bg-info rounded-pill">Bu Hafta</span>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>

            <div class="col-md-6">
                <div class="card">
                    <div class="card-header">
                        <h5 class="card-title">Hızlı İstatistikler</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-4">
                            <div class="d-flex justify-content-between mb-1">
                                <span>Bu Ay Tamamlanan Ekspertizler</span>
                                <span class="fw-bold">65%</span>
                            </div>
                            <div class="progress" style="height: 8px;">
                                <div class="progress-bar bg-success" role="progressbar" style="width: 65%;" aria-valuenow="65" aria-valuemin="0" aria-valuemax="100"></div>
                            </div>
                        </div>

                        <div class="mb-4">
                            <div class="d-flex justify-content-between mb-1">
                                <span>Sistem Kullanım Oranı</span>
                                <span class="fw-bold">82%</span>
                            </div>
                            <div class="progress" style="height: 8px;">
                                <div class="progress-bar bg-primary" role="progressbar" style="width: 82%;" aria-valuenow="82" aria-valuemin="0" aria-valuemax="100"></div>
                            </div>
                        </div>

                        <div class="mb-4">
                            <div class="d-flex justify-content-between mb-1">
                                <span>Müşteri Memnuniyeti</span>
                                <span class="fw-bold">90%</span>
                            </div>
                            <div class="progress" style="height: 8px;">
                                <div class="progress-bar bg-info" role="progressbar" style="width: 90%;" aria-valuenow="90" aria-valuemin="0" aria-valuemax="100"></div>
                            </div>
                        </div>

                        <div>
                            <div class="d-flex justify-content-between mb-1">
                                <span>Depolama Alanı Kullanımı</span>
                                <span class="fw-bold">45%</span>
                            </div>
                            <div class="progress" style="height: 8px;">
                                <div class="progress-bar bg-warning" role="progressbar" style="width: 45%;" aria-valuenow="45" aria-valuemin="0" aria-valuemax="100"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Task Modal -->
<div class="modal fade" id="taskModal" tabindex="-1" aria-labelledby="taskModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="taskModalLabel">Yeni Görev Ekle</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form>
                    <div class="mb-3">
                        <label for="taskTitle" class="form-label">Görev Başlığı</label>
                        <input type="text" class="form-control" id="taskTitle" placeholder="Görev başlığını girin">
                    </div>
                    <div class="mb-3">
                        <label for="taskDueDate" class="form-label">Son Tarih</label>
                        <input type="date" class="form-control" id="taskDueDate">
                    </div>
                    <div class="mb-3">
                        <label for="taskPriority" class="form-label">Öncelik</label>
                        <select class="form-select" id="taskPriority">
                            <option value="low">Düşük</option>
                            <option value="medium" selected>Orta</option>
                            <option value="high">Yüksek</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="taskDescription" class="form-label">Açıklama</label>
                        <textarea class="form-control" id="taskDescription" rows="3" placeholder="Görev açıklamasını girin"></textarea>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                <button type="button" class="btn btn-primary">Kaydet</button>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- ApexCharts -->
<script src="https://cdn.jsdelivr.net/npm/apexcharts@3.35.3/dist/apexcharts.min.js"></script>

<script>
    // Sidebar Toggle
    document.getElementById('toggle-sidebar').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.toggle('show');
    });

    document.getElementById('sidebar-toggle').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.remove('show');
    });

    // Charts
    document.addEventListener('DOMContentLoaded', function() {
        // Expertise Chart
        var expertiseOptions = {
            series: [{
                name: 'Ekspertiz Sayısı',
                data: [31, 40, 35, 51, 49, 62, 69, 91, 80, 85, 92, 100]
            }],
            chart: {
                height: 300,
                type: 'line',
                toolbar: {
                    show: false
                },
                zoom: {
                    enabled: false
                }
            },
            colors: ['#4361ee'],
            dataLabels: {
                enabled: false
            },
            stroke: {
                curve: 'smooth',
                width: 3
            },
            grid: {
                borderColor: '#e0e0e0',
                row: {
                    colors: ['#f8f9fa', 'transparent'],
                    opacity: 0.5
                }
            },
            xaxis: {
                categories: ['Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık'],
                labels: {
                    style: {
                        colors: '#6c757d'
                    }
                }
            },
            yaxis: {
                labels: {
                    style: {
                        colors: '#6c757d'
                    }
                }
            },
            markers: {
                size: 4,
                colors: ['#4361ee'],
                strokeColors: '#fff',
                strokeWidth: 2,
                hover: {
                    size: 7
                }
            },
            tooltip: {
                theme: 'dark'
            }
        };

        var expertiseChart = new ApexCharts(document.querySelector('#expertiseChart'), expertiseOptions);
        expertiseChart.render();

        // Status Chart
        var statusOptions = {
            series: [44, 55, 13, 43],
            chart: {
                type: 'donut',
                height: 260
            },
            labels: ['Bekliyor', 'Devam Ediyor', 'Tamamlandı', 'İptal Edildi'],
            colors: ['#eab308', '#4361ee', '#10b981', '#ef4444'],
            legend: {
                position: 'bottom',
                fontSize: '14px',
                fontFamily: 'Poppins, sans-serif',
                labels: {
                    colors: '#6c757d'
                }
            },
            stroke: {
                width: 0
            },
            dataLabels: {
                enabled: false
            },
            tooltip: {
                theme: 'dark'
            },
            plotOptions: {
                pie: {
                    donut: {
                        size: '65%',
                        labels: {
                            show: true,
                            name: {
                                show: true,
                                fontSize: '14px',
                                fontFamily: 'Poppins, sans-serif',
                                color: '#6c757d'
                            },
                            value: {
                                show: true,
                                fontSize: '20px',
                                fontFamily: 'Poppins, sans-serif',
                                color: '#212529',
                                formatter: function(val) {
                                    return val;
                                }
                            },
                            total: {
                                show: true,
                                label: 'Toplam',
                                fontSize: '14px',
                                fontFamily: 'Poppins, sans-serif',
                                color: '#6c757d',
                                formatter: function(w) {
                                    return w.globals.seriesTotals.reduce((a, b) => a + b, 0);
                                }
                            }
                        }
                    }
                }
            }
        };

        var statusChart = new ApexCharts(document.querySelector('#statusChart'), statusOptions);
        statusChart.render();
    });

    // Task Checkbox Effect
    document.querySelectorAll('.form-check-input').forEach(function(checkbox) {
        checkbox.addEventListener('change', function() {
            var label = this.nextElementSibling;
            if (this.checked) {
                label.classList.add('text-decoration-line-through');
            } else {
                label.classList.remove('text-decoration-line-through');
            }
        });
    });
</script>
</body>
</html>