<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';
require_once 'classes/Template.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// Tarih formatı ayarları
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
date_default_timezone_set('Europe/Istanbul');

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $customer = new Customer($conn);
    $template = new Template($conn);
    $user = new User($conn);

    // Kullanıcıyı getir
    $user->readOne($userId);

    // Tüm müşterileri getir
    $customers = $customer->getCustomers($companyId, 100, 0); // İlk 100 müşteri

    // Tüm ekspertiz şablonlarını getir
    $templates = $template->getTemplates($companyId);

    // Form gönderildiğinde
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Formdaki verileri al
        $customerId = isset($_POST['customer_id']) ? (int)$_POST['customer_id'] : 0;
        $vehicleId = isset($_POST['vehicle_id']) ? (int)$_POST['vehicle_id'] : 0; 
        $vehicleType = isset($_POST['vehicle_type']) ? $_POST['vehicle_type'] : 'normal';

        // Alıcı bilgileri
        $buyerName = isset($_POST['buyer_name']) ? $_POST['buyer_name'] : '';
        $buyerPhone = isset($_POST['buyer_phone']) ? $_POST['buyer_phone'] : '';
        $feeReceived = isset($_POST['fee_received']) ? $_POST['fee_received'] : '';

        // Yapılacak testler
        $tests = [
            'kaporta_test' => isset($_POST['kaporta_test']) ? 1 : 0,
            'mekanik_test' => isset($_POST['mekanik_test']) ? 1 : 0,
            'mekanik_test_2' => isset($_POST['mekanik_test_2']) ? 1 : 0,
            'motor_test' => isset($_POST['motor_test']) ? 1 : 0,
            'ariza_test' => isset($_POST['ariza_test']) ? 1 : 0,
            'beyin_test' => isset($_POST['beyin_test']) ? 1 : 0,
            'co2_test' => isset($_POST['co2_test']) ? 1 : 0,
            'sanziman' => isset($_POST['sanziman']) ? 1 : 0,
            '101_test' => isset($_POST['101_test']) ? 1 : 0,
            '501_test' => isset($_POST['501_test']) ? 1 : 0,
            'motor_performansi' => isset($_POST['motor_performansi']) ? 1 : 0
        ];

        $notes = isset($_POST['notes']) ? $_POST['notes'] : '';

        // Veri doğrulama
        $errors = [];

        if ($customerId <= 0) {
            $errors[] = "Müşteri seçimi zorunludur.";
        }

        if ($vehicleId <= 0) {
            $errors[] = "Araç seçimi zorunludur.";
        }

        if (empty($buyerName)) {
            $errors[] = "Alıcı adı zorunludur.";
        }

        // Hata yoksa ekspertiz oluştur
        if (empty($errors)) {
            // Ekspertiz kodu oluştur
            $expertiseCode = $expertise->generateExpertiseCode($companyId);

            // Ekspertiz özelliklerini ayarla
            $expertise->company_id = $companyId;
            $expertise->vehicle_id = $vehicleId;
            $expertise->customer_id = $customerId;
            $expertise->expert_id = $userId;
            $expertise->expertise_code = $expertiseCode;
            $expertise->expertise_date = date('Y-m-d H:i:s'); // Şu anki tarih
            $expertise->status = 'pending';
            $expertise->total_score = 0; // Başlangıçta puan yok
            $expertise->notes = $notes;
            $expertise->location = ''; // Boş değer atayalım

            // Yeni alanları JSON olarak ekle
            $extraData = [
                'buyer_name' => $buyerName,
                'buyer_phone' => $buyerPhone,
                'fee_received' => $feeReceived,
                'vehicle_type' => $vehicleType,
                'tests' => $tests
            ];

            $expertise->extra_data = json_encode($extraData);
            $expertise->report_url = ''; // Henüz rapor yok

            // Ekspertizi oluştur
            if ($expertise->create()) {
                // Başarılı mesajı
                $successMessage = "Ekspertiz başarıyla oluşturuldu. Kod: " . $expertiseCode;

                // Ekspertiz formuna yönlendir
                header("Location: expertise_form.php?id=" . $expertise->id);
                exit;
            } else {
                // Hata mesajı
                $errorMessage = "Ekspertiz oluşturulurken bir hata oluştu.";
            }
        } else {
            // Hata mesajlarını birleştir
            $errorMessage = implode("<br>", $errors);
        }
    }

    // Sayfa başlığı
    $pageTitle = "Yeni Ekspertiz";

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}

// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Yeni Ekspertiz - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- Select2 -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" />
    <!-- Toastr Bildirimler için -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">

    <?php include "includes/style.php"; ?>
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --success-color: #4cc9f0;
            --warning-color: #f72585;
            --danger-color: #e63946;
            --dark-color: #212529;
            --light-color: #f8f9fa;
            --sidebar-width: 250px;
            --topbar-height: 60px;
            --gradient-primary: linear-gradient(135deg, #4361ee 0%, #3a0ca3 100%);
            --shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);
            --shadow-md: 0 .5rem 1rem rgba(0, 0, 0, .15);
            --transition: all 0.3s ease;
        }

        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f9fafb;
            color: #333;
            overflow-x: hidden;
        }

        .form-label {
            font-weight: 500;
            font-size: 0.9rem;
            color: #495057;
        }

        .form-control:focus, .form-select:focus {
            border-color: var(--primary-color);
            box-shadow: 0 0 0 0.2rem rgba(67, 97, 238, 0.25);
        }

        .form-text {
            font-size: 0.75rem;
            color: #6c757d;
        }

        .required-field::after {
            content: "*";
            color: var(--danger-color);
            margin-left: 4px;
        }

        .form-section {
            background-color: #f8f9fa;
            padding: 10px 15px;
            margin-bottom: 15px;
            border-radius: 5px;
            color: var(--primary-color);
            font-weight: 600;
        }

        /* Select2 Özelleştirmeleri */
        .select2-container--bootstrap-5 .select2-selection {
            min-height: 38px;
        }

        .select2-container--bootstrap-5 .select2-selection--single {
            padding-top: 4px;
        }

        /* Yükleniyor Animasyonu */
        .loading {
            display: flex;
            align-items: center;
            justify-content: center;
            height: 200px;
        }

        .loading-spinner {
            width: 40px;
            height: 40px;
            border: 3px solid rgba(0, 0, 0, 0.1);
            border-radius: 50%;
            border-top-color: var(--primary-color);
            animation: spin 1s ease-in-out infinite;
        }

        @keyframes spin {
            to { transform: rotate(360deg); }
        }

        /* Modal özelleştirmeleri */
        .modal-header {
            background: var(--gradient-primary);
            color: white;
        }

        .modal-footer {
            border-top: 1px solid #eee;
            padding: 1rem;
        }

        /* Hızlı ekle butonları */
        .quick-add-btn {
            font-size: 0.85rem;
            padding: 0.25rem 0.5rem;
        }

        /* Araç tipi resim seçici */
        .vehicle-type-selector {
            margin: 20px 0;
        }

        .vehicle-type-selector .vehicle-type-option {
            text-align: center;
            margin-bottom: 15px;
            cursor: pointer;
        }

        .vehicle-type-selector .vehicle-type-option img {
            max-width: 100%;
            height: auto;
            border: 2px solid #ddd;
            border-radius: 5px;
            transition: all 0.3s;
        }

        .vehicle-type-selector .vehicle-type-option.selected img {
            border-color: var(--primary-color);
            box-shadow: 0 0 10px rgba(67, 97, 238, 0.5);
        }

        .vehicle-type-selector .form-check-input:checked ~ img {
            border-color: var(--primary-color);
            box-shadow: 0 0 10px rgba(67, 97, 238, 0.5);
        }
    </style>
</head>
<body>
<!-- Sidebar -->
<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->
    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header d-flex justify-content-between align-items-center">
            <div>
                <h1 class="page-title">Yeni Ekspertiz</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                        <li class="breadcrumb-item"><a href="expertises.php">Ekspertizler</a></li>
                        <li class="breadcrumb-item active" aria-current="page">Yeni Ekspertiz</li>
                    </ol>
                </nav>
            </div>
            <div>
                <a href="expertises.php" class="btn btn-secondary">
                    <i class="fas fa-arrow-left me-2"></i> Geri Dön
                </a>
            </div>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($successMessage)): ?>
            <div class="alert alert-success" role="alert">
                <i class="fas fa-check-circle me-2"></i> <?php echo $successMessage; ?>
            </div>
        <?php endif; ?>

        <!-- Form Card -->
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Ekspertiz Bilgileri</h5>
            </div>
            <div class="card-body">
                <form method="POST" action="" id="expertise-form">
                    <!-- Müşteri ve Araç Bilgileri -->
                    <div class="form-section">
                        <i class="fas fa-user-alt me-2"></i> Satıcı  Bilgileri
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="customer_id" class="form-label required-field">Satıcı</label>
                            <div class="input-group">
                                <select class="form-select" id="customer_id" name="customer_id" required>
                                    <option value="">Satıcı Seçin</option>
                                    <?php foreach ($customers as $c): ?>
                                        <option value="<?php echo $c['id']; ?>"><?php echo htmlspecialchars($c['first_name'] . ' ' . $c['last_name'] . ' - ' . $c['phone']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                                <button class="btn btn-outline-primary" type="button" data-bs-toggle="modal" data-bs-target="#customerModal">
                                    <i class="fas fa-plus"></i> Yeni
                                </button>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <label for="vehicle_id" class="form-label required-field">Araç</label>
                            <div class="input-group">
                                <select class="form-select" id="vehicle_id" name="vehicle_id" required disabled>
                                    <option value="">Önce müşteri seçin</option>
                                </select>
                                <button class="btn btn-outline-primary" type="button" id="addVehicleBtn" data-bs-toggle="modal" data-bs-target="#vehicleModal" disabled>
                                    <i class="fas fa-plus"></i> Yeni
                                </button>
                            </div>
                        </div>
                    </div>

                    <!-- Alıcı Bilgileri -->
                    <div class="form-section">
                        <i class="fas fa-id-card me-2"></i> Alıcı Bilgileri
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-4">
                            <label for="buyer_name" class="form-label required-field">Ad & Soyad</label>
                            <input type="text" class="form-control" id="buyer_name" name="buyer_name" required>
                        </div>
                        <div class="col-md-4">
                            <label for="buyer_phone" class="form-label">Telefon</label>
                            <input type="tel" class="form-control" id="buyer_phone" name="buyer_phone">
                        </div>
                        <div class="col-md-4">
                            <label for="fee_received" class="form-label">Alınan Ücret</label>
                            <div class="input-group">
                                <input type="text" class="form-control" id="fee_received" name="fee_received">
                                <span class="input-group-text">₺</span>
                            </div>
                        </div>
                    </div>

                    <!-- Araç Tipi Seçimi -->
                    <div class="form-section">
                        <i class="fas fa-car me-2"></i> Araç Tipi
                    </div>

                    <div class="vehicle-type-selector">
                        <div class="row">
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="normal" value="normal" checked>
                                        <label class="form-check-label w-100" for="normal">
                                            <img src="assets/images/car_types/normal.png" alt="Normal" class="img-fluid">
                                            <div class="mt-2">Normal</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="hatchback" value="hatchback">
                                        <label class="form-check-label w-100" for="hatchback">
                                            <img src="assets/images/car_types/hatchback.png" alt="Hatchback" class="img-fluid">
                                            <div class="mt-2">Hatchback</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="suv" value="suv">
                                        <label class="form-check-label w-100" for="suv">
                                            <img src="assets/images/car_types/suv.png" alt="SUV" class="img-fluid">
                                            <div class="mt-2">SUV/Jip</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="row mt-3">
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="panelvan" value="panelvan">
                                        <label class="form-check-label w-100" for="panelvan">
                                            <img src="assets/images/car_types/panelvan.png" alt="Panelvan" class="img-fluid">
                                            <div class="mt-2">Panelvan</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="kamyonet1" value="kamyonet1">
                                        <label class="form-check-label w-100" for="kamyonet1">
                                            <img src="assets/images/car_types/kamyonet1.png" alt="Kamyonet-1" class="img-fluid">
                                            <div class="mt-2">Kamyonet-1</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="kamyonet2" value="kamyonet2">
                                        <label class="form-check-label w-100" for="kamyonet2">
                                            <img src="assets/images/car_types/kamyonet2.png" alt="Kamyonet-2" class="img-fluid">
                                            <div class="mt-2">Kamyonet-2</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="row mt-3">
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="sedan" value="sedan">
                                        <label class="form-check-label w-100" for="sedan">
                                            <img src="assets/images/car_types/sedan.png" alt="Tek Kapı Sedan" class="img-fluid">
                                            <div class="mt-2">Tek Kapı Sedan</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="hb" value="hb">
                                        <label class="form-check-label w-100" for="hb">
                                            <img src="assets/images/car_types/hb.png" alt="Tek Kapı HB" class="img-fluid">
                                            <div class="mt-2">Tek Kapı HB</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="vehicle-type-option">
                                    <div class="form-check">
                                        <input class="form-check-input visually-hidden" type="radio" name="vehicle_type" id="kombi" value="kombi">
                                        <label class="form-check-label w-100" for="kombi">
                                            <img src="assets/images/car_types/kombi.png" alt="Kombi" class="img-fluid">
                                            <div class="mt-2">Kombi</div>
                                        </label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>


                    <!-- Yapılacak Testler -->
                    <div class="form-section">
                        <i class="fas fa-vial me-2"></i> Yapılacak Testler
                    </div>

                    <div class="row mb-3">
                        <div class="col-md-3">
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="kaporta_test" id="kaporta_test" value="1">
                                <label class="form-check-label" for="kaporta_test">Kaporta Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="mekanik_test" id="mekanik_test" value="1">
                                <label class="form-check-label" for="mekanik_test">Mekanik Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="mekanik_test_2" id="mekanik_test_2" value="1">
                                <label class="form-check-label" for="mekanik_test_2">Mekanik Test 2</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="motor_test" id="motor_test" value="1">
                                <label class="form-check-label" for="motor_test">Motor Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="ariza_test" id="ariza_test" value="1">
                                <label class="form-check-label" for="ariza_test">Arıza Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="beyin_test" id="beyin_test" value="1">
                                <label class="form-check-label" for="beyin_test">Beyin Test</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="co2_test" id="co2_test" value="1">
                                <label class="form-check-label" for="co2_test">CO2 Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="sanziman" id="sanziman" value="1">
                                <label class="form-check-label" for="sanziman">Şanzıman</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="101_test" id="101_test" value="1">
                                <label class="form-check-label" for="101_test">101 Test</label>
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="501_test" id="501_test" value="1">
                                <label class="form-check-label" for="501_test">501 Test</label>
                            </div>
                            <div class="form-check mb-2">
                                <input class="form-check-input" type="checkbox" name="motor_performansi" id="motor_performansi" value="1">
                                <label class="form-check-label" for="motor_performansi">Motor Performansı</label>
                            </div>
                        </div>
                    </div>

                    <div class="mb-3">
                        <label for="notes" class="form-label">Notlar</label>
                        <textarea class="form-control" id="notes" name="notes" rows="3" placeholder="Ekspertiz ile ilgili notlar..."></textarea>
                    </div>

                    <div class="d-flex justify-content-end mt-4">
                        <button type="button" class="btn btn-secondary me-2" onclick="window.location.href='expertises.php'">
                            <i class="fas fa-times me-2"></i> İptal
                        </button>
                        <button type="submit" class="btn btn-primary" id="submit-btn">
                            <i class="fas fa-save me-2"></i> Ekspertizi Başlat
                        </button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Müşteri Ekleme Modal -->
<div class="modal fade" id="customerModal" tabindex="-1" aria-labelledby="customerModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="customerModalLabel">Yeni Müşteri Ekle</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Kapat"></button>
            </div>
            <div class="modal-body">
                <form id="customerForm">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="first_name" class="form-label required-field">Ad</label>
                            <input type="text" class="form-control" id="first_name" name="first_name" required>
                        </div>
                        <div class="col-md-6">
                            <label for="last_name" class="form-label required-field">Soyad</label>
                            <input type="text" class="form-control" id="last_name" name="last_name" required>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="phone" class="form-label required-field">Telefon</label>
                            <input type="tel" class="form-control" id="phone" name="phone" required>
                        </div>
                        <div class="col-md-6">
                            <label for="identity_number" class="form-label">TC Kimlik No</label>
                            <input type="text" class="form-control" id="identity_number" name="identity_number" maxlength="11">
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="email" class="form-label">E-posta</label>
                            <input type="email" class="form-control" id="email" name="email">
                        </div>
                        <div class="col-md-6">
                            <label for="city" class="form-label">Şehir</label>
                            <input type="text" class="form-control" id="city" name="city">
                        </div>
                    </div>
                    <div class="mb-3">
                        <label for="address" class="form-label">Adres</label>
                        <textarea class="form-control" id="address" name="address" rows="2"></textarea>
                    </div>
                    <input type="hidden" name="company_id" value="<?php echo $companyId; ?>">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                <button type="button" class="btn btn-primary" id="saveCustomerBtn">Müşteri Ekle</button>
            </div>
        </div>
    </div>
</div>

<!-- Araç Ekleme Modal -->
<div class="modal fade" id="vehicleModal" tabindex="-1" aria-labelledby="vehicleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="vehicleModalLabel">Yeni Araç Ekle</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Kapat"></button>
            </div>
            <div class="modal-body">
                <form id="vehicleForm">
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="selected_customer" class="form-label">Seçili Müşteri</label>
                            <input type="text" class="form-control" id="selected_customer" readonly>
                            <input type="hidden" id="vehicle_customer_id" name="customer_id">
                        </div>
                        <div class="col-md-6">
                            <label for="plate_number" class="form-label required-field">Plaka</label>
                            <input type="text" class="form-control" id="plate_number" name="plate_number" required>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-4">
                            <label for="brand" class="form-label required-field">Marka</label>
                            <input type="text" class="form-control" id="brand" name="brand" required>
                            <!-- Gizli brand_id alanı -->
                            <input type="hidden" id="brand_id" name="brand_id" value="1">
                        </div>
                        <div class="col-md-4">
                            <label for="model" class="form-label required-field">Model</label>
                            <input type="text" class="form-control" id="model" name="model" required>
                            <!-- Gizli model_id alanı -->
                            <input type="hidden" id="model_id" name="model_id" value="1">
                        </div>
                        <div class="col-md-4">
                            <label for="year" class="form-label required-field">Yıl</label>
                            <input type="number" class="form-control" id="year" name="year" min="1900" max="<?php echo date('Y'); ?>" required>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="color" class="form-label">Renk</label>
                            <input type="text" class="form-control" id="color" name="color">
                        </div>
                        <div class="col-md-6">
                            <label for="chassis_number" class="form-label">Şasi No</label>
                            <input type="text" class="form-control" id="chassis_number" name="chassis_number">
                        </div>
                    </div>
                    <!-- Ek araç bilgileri -->
                    <div class="row mb-3">
                        <div class="col-md-4">
                            <label for="fuel_type" class="form-label">Yakıt Tipi</label>
                            <select class="form-select" id="fuel_type" name="fuel_type">
                                <option value="">Seçiniz</option>
                                <option value="Benzin">Benzin</option>
                                <option value="Dizel">Dizel</option>
                                <option value="LPG">LPG</option>
                                <option value="Elektrik">Elektrik</option>
                                <option value="Hibrit">Hibrit</option>
                            </select>
                        </div>
                        <div class="col-md-4">
                            <label for="transmission" class="form-label">Şanzıman</label>
                            <select class="form-select" id="transmission" name="transmission">
                                <option value="">Seçiniz</option>
                                <option value="Manuel">Manuel</option>
                                <option value="Otomatik">Otomatik</option>
                                <option value="Yarı Otomatik">Yarı Otomatik</option>
                            </select>
                        </div>
                        <div class="col-md-4">
                            <label for="mileage" class="form-label">Kilometre</label>
                            <input type="number" class="form-control" id="mileage" name="mileage" min="0">
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-md-6">
                            <label for="engine_size" class="form-label">Motor Hacmi</label>
                            <input type="text" class="form-control" id="engine_size" name="engine_size" placeholder="örn: 1.6">
                        </div>
                        <div class="col-md-6">
                            <label for="engine_power" class="form-label">Motor Gücü</label>
                            <input type="text" class="form-control" id="engine_power" name="engine_power" placeholder="örn: 110 HP">
                        </div>
                    </div>
                    <input type="hidden" name="company_id" value="<?php echo $companyId; ?>">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">İptal</button>
                <button type="button" class="btn btn-primary" id="saveVehicleBtn">Araç Ekle</button>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Select2 -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<!-- Toastr JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>

<!-- Custom JS -->
<script>
    // Toastr bildirim ayarları
    toastr.options = {
        "closeButton": true,
        "progressBar": true,
        "positionClass": "toast-top-right",
        "timeOut": "3000"
    };

    // Sidebar Toggle
    document.getElementById('toggle-sidebar').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.toggle('show');
    });

    document.getElementById('sidebar-toggle').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.remove('show');
    });

    // Initialize Select2
    $(document).ready(function() {
        $('#customer_id').select2({
            theme: 'bootstrap-5',
            placeholder: 'Müşteri Seçin',
            allowClear: true,
            dropdownParent: $('#customer_id').parent()
        });

        $('#vehicle_id').select2({
            theme: 'bootstrap-5',
            placeholder: 'Araç Seçin',
            allowClear: true,
            dropdownParent: $('#vehicle_id').parent()
        });


        // Araç tipi seçimi
        $('.vehicle-type-option input[type="radio"]').change(function() {
            // Önce tüm seçimleri kaldır
            $('.vehicle-type-option').removeClass('selected');
            // Seçilen araca selected class ekle
            $(this).closest('.vehicle-type-option').addClass('selected');
        });

        // Sayfa yüklendiğinde default seçili araç tipini işaretle
        $('.vehicle-type-option input[type="radio"]:checked').closest('.vehicle-type-option').addClass('selected');
    });

    // Müşteri değiştiğinde araçları getir
    $('#customer_id').on('change', function() {
        const customerId = $(this).val();
        const vehicleSelect = $('#vehicle_id');
        const addVehicleBtn = $('#addVehicleBtn');

        if (customerId) {
            // Yeni araç butonunu etkinleştir
            addVehicleBtn.prop('disabled', false);

            // Müşteri bilgilerini araç modalına aktar
            $('#vehicle_customer_id').val(customerId);
            const selectedCustomerText = $('#customer_id option:selected').text();
            $('#selected_customer').val(selectedCustomerText);

            // Araç seçimini etkinleştir
            vehicleSelect.prop('disabled', false);

            // Yükleniyor
            vehicleSelect.html('<option value="">Yükleniyor...</option>');

            // Araçları AJAX ile getir
            $.ajax({
                url: 'ajax/get_vehicles.php',
                type: 'GET',
                data: {
                    customer_id: customerId
                },
                dataType: 'json',
                success: function(data) {
                    vehicleSelect.html('<option value="">Araç Seçin</option>');

                    if (data.success && data.vehicles.length > 0) {
                        // Araçları listeye ekle
                        $.each(data.vehicles, function(i, vehicle) {
                            vehicleSelect.append(
                                $('<option>', {
                                    value: vehicle.id,
                                    text: vehicle.vehicle_name + ' (' + vehicle.plate_number + ')'
                                })
                            );
                        });
                    } else {
                        // Araç bulunamadı
                        vehicleSelect.html('<option value="">Araç bulunamadı</option>');
                    }
                },
                error: function() {
                    vehicleSelect.html('<option value="">Araçlar yüklenemedi</option>');
                }
            });
        } else {
            // Müşteri seçilmediğinde araç seçimini devre dışı bırak
            vehicleSelect.html('<option value="">Önce müşteri seçin</option>');
            vehicleSelect.prop('disabled', true);
            addVehicleBtn.prop('disabled', true);
        }
    });

    // Yeni müşteri ekle
    $('#saveCustomerBtn').on('click', function() {
        const btn = $(this);
        const form = $('#customerForm');

        // Form doğrulama - Basit kontrol
        if (!form[0].checkValidity()) {
            form[0].reportValidity();
            return;
        }

        // Buton durumunu güncelle
        btn.prop('disabled', true).html('<span class="spinner-border spinner-border-sm me-2"></span> Kaydediliyor...');

        // Form verilerini topla
        const formData = form.serialize();

        // AJAX isteği
        $.ajax({
            url: 'ajax/add_customer.php',
            type: 'POST',
            data: formData,
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    // Bildirimi göster
                    toastr.success('Müşteri başarıyla eklendi');

                    // Müşteri select listesini güncelle
                    const customerSelect = $('#customer_id');
                    customerSelect.append(
                        $('<option>', {
                            value: response.customer_id,
                            text: response.customer_name
                        })
                    );

                    // Yeni eklenen müşteriyi seç
                    customerSelect.val(response.customer_id).trigger('change');

                    // Modalı kapat
                    $('#customerModal').modal('hide');

                    // Formu sıfırla
                    form[0].reset();
                } else {
                    // Hata mesajını göster
                    toastr.error(response.message || 'Müşteri eklenirken bir hata oluştu');
                }
            },
            error: function() {
                toastr.error('Sunucu hatası. Lütfen daha sonra tekrar deneyin.');
            },
            complete: function() {
                // Buton durumunu geri al
                btn.prop('disabled', false).html('Müşteri Ekle');
            }
        });
    });

    // Yeni araç ekle
    $('#saveVehicleBtn').on('click', function() {
        const btn = $(this);
        const form = $('#vehicleForm');

        // Form doğrulama - Basit kontrol
        if (!form[0].checkValidity()) {
            form[0].reportValidity();
            return;
        }

        // Buton durumunu güncelle
        btn.prop('disabled', true).html('<span class="spinner-border spinner-border-sm me-2"></span> Kaydediliyor...');

        // Form verilerini formData olarak topla
        const formData = new FormData(form[0]);

        // brand_id ve model_id değerlerini manuel ekle
        if (!formData.has('brand_id') || formData.get('brand_id') === '') {
            formData.set('brand_id', '1'); // Kesin değer belirle
        }

        if (!formData.has('model_id') || formData.get('model_id') === '') {
            formData.set('model_id', '1'); // Kesin değer belirle
        }

        // AJAX isteği
        $.ajax({
            url: 'ajax/add_vehicle.php',
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    // Bildirimi göster
                    toastr.success('Araç başarıyla eklendi');

                    // Araç select listesini güncelle
                    const vehicleSelect = $('#vehicle_id');
                    vehicleSelect.append(
                        $('<option>', {
                            value: response.vehicle_id,
                            text: response.vehicle_name
                        })
                    );

                    // Yeni eklenen aracı seç
                    vehicleSelect.val(response.vehicle_id).trigger('change');

                    // Modalı kapat
                    $('#vehicleModal').modal('hide');

                    // Formu sıfırla
                    form[0].reset();
                } else {
                    // Hata mesajını göster
                    toastr.error(response.message || 'Araç eklenirken bir hata oluştu');
                }
            },
            error: function() {
                toastr.error('Sunucu hatası. Lütfen daha sonra tekrar deneyin.');
            },
            complete: function() {
                // Buton durumunu geri al
                btn.prop('disabled', false).html('Araç Ekle');
            }
        });
    });

    // Form gönderildiğinde butonları devre dışı bırak
    $('#expertise-form').on('submit', function() {
        $('#submit-btn').prop('disabled', true).html('<span class="spinner-border spinner-border-sm me-2" role="status" aria-hidden="true"></span> İşleniyor...');
    });
</script>
</body>
</html>