<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';
require_once 'classes/Template.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// Tarih formatı ayarları
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
date_default_timezone_set('Europe/Istanbul');

// ID parametresi kontrol
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: expertises.php");
    exit;
}

$expertiseId = (int)$_GET['id'];

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $customer = new Customer($conn);
    $user = new User($conn);

    // Ekspertiz detaylarını getir
    $expertiseDetails = $expertise->readOne($expertiseId);

    // Ekspertiz bulunamadıysa veya başka şirkete aitse reddet
    if (!$expertiseDetails || $expertiseDetails['company_id'] != $companyId) {
        header("Location: expertises.php");
        exit;
    }

    // Araç bilgilerini getir
    $vehicleDetails = $vehicle->readOne($expertiseDetails['vehicle_id']);

    // Müşteri bilgilerini getir
    $customerDetails = $customer->readOne($expertiseDetails['customer_id']);

    // Eksper bilgilerini getir
    $expertDetails = $user->readOne($expertiseDetails['expert_id']);

    // Ekspertiz extra data'sını decode et
    $extraData = isset($expertiseDetails['extra_data']) && !empty($expertiseDetails['extra_data'])
        ? json_decode($expertiseDetails['extra_data'], true)
        : [];

    // Test data
    $tests = isset($extraData['tests']) ? $extraData['tests'] : [];

    // Alıcı bilgileri
    $buyerName = isset($extraData['buyer_name']) ? $extraData['buyer_name'] : '';
    $buyerPhone = isset($extraData['buyer_phone']) ? $extraData['buyer_phone'] : '';
    $feeReceived = isset($extraData['fee_received']) ? $extraData['fee_received'] : '';

    // Araç tipi
    $vehicleType = isset($extraData['vehicle_type']) ? $extraData['vehicle_type'] : 'normal';

    // POST işlemi - Test tamamlama
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        if (isset($_POST['complete_test']) && isset($_POST['test_type'])) {
            $testType = $_POST['test_type'];

            // Mevcut testleri güncelle
            $tests[$testType] = 2; // 2 = Tamamlandı

            // Extra data'yı güncelle
            $extraData['tests'] = $tests;
            $expertise->extra_data = json_encode($extraData);
            $expertise->id = $expertiseId;

            if ($expertise->updateExtraData()) {
                $successMessage = str_replace("_", " ", ucfirst($testType)) . " başarıyla tamamlandı.";

                // Sayfayı yenile (PRG pattern)
                header("Location: expertise_form.php?id=" . $expertiseId . "&success=" . urlencode($successMessage));
                exit;
            } else {
                $errorMessage = "Test durumu güncellenirken bir hata oluştu.";
            }
        }

        // Ekspertiz notu kaydetme
        if (isset($_POST['save_note'])) {
            $expertNote = isset($_POST['expert_note']) ? trim($_POST['expert_note']) : '';

            // Notu güncelle
            $expertise->id = $expertiseId;
            $expertise->notes = $expertNote;

            if ($expertise->updateNotes()) {
                $successMessage = "Ekspertiz notu başarıyla kaydedildi.";

                // Sayfayı yenile
                header("Location: expertise_form.php?id=" . $expertiseId . "&success=" . urlencode($successMessage));
                exit;
            } else {
                $errorMessage = "Not kaydedilirken bir hata oluştu.";
            }
        }

        // Tüm testleri tamamla
        if (isset($_POST['complete_all_tests'])) {
            $allTests = [
                'kaporta_test', 'mekanik_test', 'mekanik_test_2', 'motor_test',
                'ariza_test', 'beyin_test', 'co2_test', 'sanziman',
                '101_test', '501_test', 'motor_performansi'
            ];

            foreach ($allTests as $test) {
                if (isset($tests[$test]) && $tests[$test] == 1) {
                    $tests[$test] = 2; // 2 = Tamamlandı
                }
            }

            // Extra data'yı güncelle
            $extraData['tests'] = $tests;
            $expertise->extra_data = json_encode($extraData);
            $expertise->id = $expertiseId;

            if ($expertise->updateExtraData()) {
                $successMessage = "Tüm testler başarıyla tamamlandı.";

                // Ekspertiz durumunu tamamlandı olarak işaretle
                $expertise->status = 'completed';
                $expertise->updateStatus();

                // Sayfayı yenile
                header("Location: expertise_form.php?id=" . $expertiseId . "&success=" . urlencode($successMessage));
                exit;
            } else {
                $errorMessage = "Testler güncellenirken bir hata oluştu.";
            }
        }
    }

    // Success mesajı
    if (isset($_GET['success'])) {
        $successMessage = $_GET['success'];
    }

    // Sayfa başlığı
    $pageTitle = "Ekspertiz Formu - " . $expertiseDetails['expertise_code'];

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}

// Araç tipi görsellerinin adları
$vehicleTypeImages = [
    'normal' => 'normal.png',
    'hatchback' => 'hatchback.png',
    'suv' => 'suv.png',
    'panelvan' => 'panelvan.png',
    'kamyonet1' => 'kamyonet1.png',
    'kamyonet2' => 'kamyonet2.png',
    'sedan' => 'sedan.png',
    'hb' => 'hb.png',
    'kombi' => 'kombi.png'
];
$testNames = [
    'kaporta_test' => 'Kaporta Testi',
    'mekanik_test' => 'Mekanik Test',
    'mekanik_test_2' => 'Mekanik Test 2',
    'motor_test' => 'Motor Testi'
];

// Sadece gösterilecek testlerin anahtarlarını içeren dizi
$showOnlyTheseTests = array_keys($testNames);

// Test ikonları
$testIcons = [
    'kaporta_test' => '<i class="fas fa-car"></i>',
    'mekanik_test' => '<i class="fas fa-wrench"></i>',
    'mekanik_test_2' => '<i class="fas fa-cogs"></i>',
    'motor_test' => '<i class="fas fa-tachometer-alt"></i>',
    'ariza_test' => '<i class="fas fa-exclamation-triangle"></i>',
    'beyin_test' => '<i class="fas fa-microchip"></i>',
    'co2_test' => '<i class="fas fa-smog"></i>',
    'sanziman' => '<i class="fas fa-cog"></i>',
    '101_test' => '<i class="fas fa-check-double"></i>',
    '501_test' => '<i class="fas fa-clipboard-check"></i>',
    'motor_performansi' => '<i class="fas fa-bolt"></i>'
];

// Test renklerini tanımla
$testColors = [
    'kaporta_test' => '#1abc9c',
    'mekanik_test' => '#3498db',
    'mekanik_test_2' => '#2980b9',
    'motor_test' => '#e74c3c',
    'ariza_test' => '#f39c12',
    'beyin_test' => '#9b59b6',
    'co2_test' => '#27ae60',
    'sanziman' => '#16a085',
    'fotograf_cek' => '#f1c40f',
    '101_test' => '#34495e',
    '501_test' => '#8e44ad',
    'motor_performansi' => '#d35400'
];
// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- Toastr Bildirimler için -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css">
    <!-- Dropzone CSS -->
    <link rel="stylesheet" href="https://unpkg.com/dropzone@5/dist/min/dropzone.min.css" type="text/css" />
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">

    <?php include "includes/style.php"; ?>
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --success-color: #4cc9f0;
            --warning-color: #f72585;
            --danger-color: #e63946;
            --dark-color: #212529;
            --light-color: #f8f9fa;
            --sidebar-width: 250px;
            --topbar-height: 60px;
            --gradient-primary: linear-gradient(135deg, #4361ee 0%, #3a0ca3 100%);
            --shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);
            --shadow-md: 0 .5rem 1rem rgba(0, 0, 0, .15);
            --shadow-lg: 0 1rem 3rem rgba(0, 0, 0, .175);
            --transition: all 0.3s ease;
        }

        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f9fafb;
            color: #333;
            overflow-x: hidden;
        }

        .expertise-card {
            border-radius: 12px;
            overflow: hidden;
            box-shadow: var(--shadow-md);
            border: none;
            margin-bottom: 1.5rem;
            transition: var(--transition);
        }

        .expertise-card:hover {
            box-shadow: var(--shadow-lg);
            transform: translateY(-5px);
        }

        .card-header-tab {
            background: var(--gradient-primary);
            color: white;
            font-weight: 600;
            padding: 1rem 1.5rem;
            display: flex;
            align-items: center;
            justify-content: space-between;
        }

        .vehicle-info-box {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .vehicle-info-list {
            list-style: none;
            padding: 0;
            margin: 0;
        }

        .vehicle-info-list li {
            padding: 6px 0;
            border-bottom: 1px solid #eee;
            display: flex;
            align-items: center;
        }

        .vehicle-info-list li:last-child {
            border-bottom: none;
        }

        .vehicle-info-list .info-label {
            font-weight: 500;
            color: #555;
            width: 100px;
        }

        .vehicle-info-list .info-value {
            font-weight: 600;
            color: #333;
        }

        .edit-button {
            background-color: transparent;
            color: white;
            border: 1px solid rgba(255, 255, 255, 0.5);
            border-radius: 4px;
            padding: 4px 12px;
            font-size: 0.85rem;
            transition: var(--transition);
        }

        .edit-button:hover {
            background-color: rgba(255, 255, 255, 0.1);
            border-color: white;
        }

        .test-card {
            border-radius: 10px;
            overflow: hidden;
            box-shadow: var(--shadow-sm);
            margin-bottom: 20px;
            transition: var(--transition);
            border: none;
            height: 100%;
        }

        .test-card:hover {
            box-shadow: var(--shadow-md);
            transform: translateY(-3px);
        }

        .test-card .card-body {
            padding: 1.25rem;
        }

        .test-card .test-icon {
            font-size: 2.5rem;
            margin-bottom: 15px;
            color: white;
            height: 80px;
            width: 80px;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 50%;
        }

        .test-card .card-title {
            font-weight: 600;
            margin-bottom: 0.75rem;
        }

        .test-card .btn-complete {
            width: 100%;
            margin-top: 1rem;
            font-weight: 500;
            border: none;
            color: white;
        }

        .test-card .btn-complete:hover {
            opacity: 0.9;
        }

        .test-card.completed {
            opacity: 0.7;
        }

        .test-card.completed .test-status {
            background-color: #28a745;
            color: white;
            font-size: 0.85rem;
            padding: 4px 10px;
            border-radius: 4px;
            font-weight: 500;
            display: inline-flex;
            align-items: center;
        }

        .test-card.completed .test-status i {
            margin-right: 5px;
        }

        .expertise-completed-message {
            background-color: #d4edda;
            color: #155724;
            padding: 15px 20px;
            border-radius: 8px;
            margin-bottom: 20px;
            display: flex;
            align-items: center;
            font-weight: 500;
        }

        .expertise-completed-message i {
            font-size: 1.5rem;
            margin-right: 15px;
        }

        .complete-all-tests-btn {
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 1rem;
            border-radius: 10px;
            background: var(--gradient-primary);
            color: white;
            font-weight: 600;
            text-align: center;
            margin: 1.5rem 0;
            box-shadow: var(--shadow-md);
            border: none;
            transition: var(--transition);
        }

        .complete-all-tests-btn:hover {
            box-shadow: var(--shadow-lg);
            transform: translateY(-2px);
        }

        .complete-all-tests-btn i {
            font-size: 1.5rem;
            margin-right: 0.75rem;
        }

        .expert-note-card {
            border-radius: 10px;
            box-shadow: var(--shadow-md);
            border: none;
        }

        .expert-note-card .card-header {
            background-color: #4361ee;
            color: white;
            font-weight: 600;
            padding: 1rem 1.5rem;
        }

        .vehicle-type-image {
            max-width: 100%;
            height: auto;
            margin: 20px 0;
        }

        .buyer-info {
            background-color: #e8f4f8;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .buyer-info-title {
            font-weight: 600;
            color: #0c63e4;
            margin-bottom: 10px;
            display: flex;
            align-items: center;
        }

        .buyer-info-title i {
            margin-right: 8px;
        }

        .buyer-info-list {
            list-style: none;
            padding: 0;
            margin: 0;
        }

        .buyer-info-list li {
            padding: 6px 0;
            border-bottom: 1px solid #d1e7f0;
            display: flex;
            align-items: center;
        }

        .buyer-info-list li:last-child {
            border-bottom: none;
        }

        .buyer-info-list .info-label {
            font-weight: 500;
            color: #555;
            width: 120px;
        }

        .buyer-info-list .info-value {
            font-weight: 600;
            color: #333;
        }

        .section-title {
            font-size: 1.5rem;
            font-weight: 600;
            margin-bottom: 1.5rem;
            color: #2c3e50;
            position: relative;
            padding-bottom: 0.5rem;
        }

        .section-title::after {
            content: '';
            position: absolute;
            left: 0;
            bottom: 0;
            width: 50px;
            height: 3px;
            background: var(--primary-color);
            border-radius: 2px;
        }

        /* Dropzone Özelleştirme */
        .dropzone {
            border: 2px dashed #4361ee;
            border-radius: 10px;
            background: #f8fafc;
            min-height: 150px;
            padding: 20px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: all 0.3s ease;
        }

        .dropzone:hover {
            background: #f1f5f9;
            border-color: #3a0ca3;
        }

        .dropzone .dz-message {
            font-weight: 500;
            text-align: center;
            margin: 2em 0;
        }

        .dropzone .dz-preview {
            margin: 10px;
        }

        .photo-gallery-container {
            margin-top: 20px;
        }

        .photo-thumbnail {
            border-radius: 8px;
            overflow: hidden;
            box-shadow: var(--shadow-sm);
            margin-bottom: 15px;
            transition: var(--transition);
            height: 100%;
        }

        .photo-thumbnail:hover {
            transform: scale(1.03);
            box-shadow: var(--shadow-md);
        }

        .photo-thumbnail img {
            width: 100%;
            height: 160px;
            object-fit: cover;
        }

        .photo-actions {
            padding: 10px;
            text-align: center;
            background: #f8f9fa;
        }

        @media (max-width: 768px) {
            .test-card {
                margin-bottom: 15px;
            }

            .vehicle-info-list .info-label {
                width: 80px;
                font-size: 0.9rem;
            }

            .vehicle-info-list .info-value {
                font-size: 0.9rem;
            }
        }
    </style>
</head>
<body>
<!-- Sidebar -->
<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->
    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header d-flex justify-content-between align-items-center">
            <div>
                <h1 class="page-title">Ekspertiz Formu</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                        <li class="breadcrumb-item"><a href="expertises.php">Ekspertizler</a></li>
                        <li class="breadcrumb-item active" aria-current="page"><?php echo htmlspecialchars($expertiseDetails['expertise_code']); ?></li>
                    </ol>
                </nav>
            </div>
            <div>
                <a href="expertises.php" class="btn btn-secondary">
                    <i class="fas fa-arrow-left me-2"></i> Geri Dön
                </a>
                <?php if (isset($expertiseDetails['status']) && $expertiseDetails['status'] == 'completed'): ?>
                    <a href="generate_report.php?id=<?php echo $expertiseId; ?>" class="btn btn-success ms-2">
                        <i class="fas fa-file-pdf me-2"></i> Rapor Oluştur
                    </a>
                <?php endif; ?>
            </div>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($successMessage)): ?>
            <div class="alert alert-success" role="alert">
                <i class="fas fa-check-circle me-2"></i> <?php echo $successMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($expertiseDetails['status']) && $expertiseDetails['status'] == 'completed'): ?>
            <div class="expertise-completed-message">
                <i class="fas fa-check-circle"></i>
                <span>Bu ekspertiz tamamlanmıştır. Rapor oluşturmak için üstteki "Rapor Oluştur" butonunu kullanabilirsiniz.</span>
            </div>
        <?php endif; ?>

        <div class="row">
            <!-- Sol Kolon: Araç Bilgileri -->
            <div class="col-lg-4">
                <!-- Araç Bilgileri Kartı -->
                <div class="expertise-card">
                    <div class="card-header-tab">
                        <span>Araç Bilgileri</span>
                        <a href="edit_vehicle.php?id=<?php echo $vehicleDetails['id']; ?>" class="edit-button">
                            <i class="fas fa-edit me-1"></i> Düzenle
                        </a>
                    </div>
                    <div class="card-body">
                        <div class="vehicle-info-box">
                            <ul class="vehicle-info-list">
                                <li>
                                    <span class="info-label">Plaka:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['plate_number']); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Şasi No:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['vin_number'] ?: 'Belirtilmemiş'); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Marka:</span>

                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['brand_name']); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Model:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['model_name']); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Model Yılı:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['year']); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Renk:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['color'] ?: 'Belirtilmemiş'); ?></span>
                                </li>
<!--                                --><?php //var_dump($vehicleDetails); ?>
                                <li>
                                    <span class="info-label">Yakıt Cinsi:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['fuel_type'] ?: 'Belirtilmemiş'); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Araç KM:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['mileage'] ? number_format($vehicleDetails['mileage'], 0, ',', '.') : 'Belirtilmemiş'); ?></span>
                                </li>
                                <li>
                                    <span class="info-label">Şanzıman:</span>
                                    <span class="info-value"><?php echo htmlspecialchars($vehicleDetails['transmission'] ?: 'Belirtilmemiş'); ?></span>
                                </li>
                            </ul>
                        </div>

                        <!-- Araç tipi görseli -->
                        <div class="text-center">
                            <img src="assets/images/car_types/<?php echo isset($vehicleTypeImages[$vehicleType]) ? $vehicleTypeImages[$vehicleType] : 'normal.png'; ?>" alt="<?php echo ucfirst($vehicleType); ?>" class="vehicle-type-image">
                        </div>
                    </div>
                </div>

                <!-- Alıcı Bilgileri -->
                <?php if (!empty($buyerName)): ?>
                    <div class="expertise-card">
                        <div class="card-header-tab">
                            <span>Alıcı Bilgileri</span>
                        </div>
                        <div class="card-body">
                            <div class="buyer-info">
                                <ul class="buyer-info-list">
                                    <li>
                                        <span class="info-label">Ad Soyad:</span>
                                        <span class="info-value"><?php echo htmlspecialchars($buyerName); ?></span>
                                    </li>
                                    <?php if (!empty($buyerPhone)): ?>
                                        <li>
                                            <span class="info-label">Telefon:</span>
                                            <span class="info-value"><?php echo htmlspecialchars($buyerPhone); ?></span>
                                        </li>
                                    <?php endif; ?>
                                    <?php if (!empty($feeReceived)): ?>
                                        <li>
                                            <span class="info-label">Alınan Ücret:</span>
                                            <span class="info-value"><?php echo htmlspecialchars($feeReceived); ?> ₺</span>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <!-- Ekspertiz Notları -->
                <div class="expert-note-card">
                    <div class="card-header">
                        <i class="fas fa-clipboard-list me-2"></i> Ekspertiz Notları
                    </div>

                    <div class="card-body">
                        <form method="POST" action="">
                            <div class="mb-3">
                                <textarea class="form-control" id="expert_note" name="expert_note" rows="5" placeholder="Ekspertiz ile ilgili notlarınız..."><?php echo htmlspecialchars($expertiseDetails['notes'] ?? ''); ?></textarea>
                            </div>
                            <button type="submit" name="save_note" class="btn btn-primary w-100">
                                <i class="fas fa-save me-2"></i> Notu Kaydet
                            </button>
                        </form>
                    </div>
                </div>
            </div>

            <!-- Sağ Kolon: Testler -->
            <div class="col-lg-8">
                <h4 class="section-title"><i class="fas fa-vial me-2"></i> Yapılacak Testler</h4>

                <!-- Test butonlarını göster -->
                <!-- Test butonlarını göster -->

                <!-- Test butonlarını göster -->
                <div class="row">
                    <?php
                    // Eğer hiç test seçilmemişse mesaj göster
                    if (empty($tests)):
                        ?>
                        <div class="col-12">
                            <div class="alert alert-info" role="alert">
                                <i class="fas fa-info-circle me-2"></i> Henüz hiç test seçilmemiş. Lütfen önce test seçimi yapın.
                            </div>
                        </div>
                    <?php else: ?>
                        <?php
                        foreach ($tests as $testKey => $testStatus):
                            // Sadece belirtilen testleri göster
                            if (in_array($testKey, ['kaporta_test', 'mekanik_test', 'mekanik_test_2', 'motor_test'])):
                                $testName = isset($testNames[$testKey]) ? $testNames[$testKey] : ucfirst(str_replace('_', ' ', $testKey));
                                $testIcon = isset($testIcons[$testKey]) ? $testIcons[$testKey] : '<i class="fas fa-check"></i>';
                                $testColor = isset($testColors[$testKey]) ? $testColors[$testKey] : '#3498db';
                                $isCompleted = ($testStatus == 2); // 2 = Tamamlandı
                                ?>
                                <div class="col-md-3 col-sm-6">
                                    <div class="test-card <?php echo $isCompleted ? 'completed' : ''; ?>">
                                        <div class="card-body text-center">
                                            <div class="test-icon mx-auto" style="background-color: <?php echo $testColor; ?>">
                                                <?php echo $testIcon; ?>
                                            </div>
                                            <h5 class="card-title"><?php echo $testName; ?></h5>

                                            <?php if ($isCompleted): ?>
                                                <div class="test-status">
                                                    <i class="fas fa-check-circle"></i> Tamamlandı
                                                </div>
                            <?php endif; ?>
                                                <?php if ($testKey == 'motor_test'): ?>
                                                    <!-- Motor testi için özel yönlendirme -->
                                                    <a href="motor_test.php?expertise_id=<?php echo $expertiseId; ?>" class="btn btn-complete" style="background-color: <?php echo $testColor; ?>;">
                                                        <i class="fas fa-cogs me-2"></i> Motor Testine Git
                                                    </a>
                                                <?php elseif ($testKey == 'kaporta_test'): ?>
                                                    <!-- Kaporta testi için özel yönlendirme -->
                                                    <a href="kaporta_test.php?expertise_id=<?php echo $expertiseId; ?>" class="btn btn-complete" style="background-color: <?php echo $testColor; ?>;">
                                                        <i class="fas fa-car-crash me-2"></i> Kaporta Testine Git
                                                    </a>
                                                <?php else: ?>
                                                    <!-- Diğer testler için normal form -->
                                                    <form method="POST" action="">
                                                        <input type="hidden" name="test_type" value="<?php echo $testKey; ?>">
                                                        <button type="submit" name="complete_test" class="btn btn-complete" style="background-color: <?php echo $testColor; ?>;">
                                                            <i class="fas fa-check me-2"></i> Testi Tamamla
                                                        </button>
                                                    </form> 
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            <?php
                            endif;
                        endforeach;
                        ?>
                    <?php endif; ?>
                </div>

                <!-- Tüm testleri tamamla butonu -->
                <?php
                // Tüm testleri tamamla butonu
                // Not: Burada `updateExtraData()` ve diğer işlemler yapıldığında,
                // diğer tüm testler de işaretleniyor, ama kullanıcı arayüzünde sadece belirli testler gösteriliyor
                $pendingTests = false;
                foreach ($tests as $testKey => $testStatus) {
                    if ($testStatus == 1) { // 1 = Bekliyor
                        $pendingTests = true;
                        break;
                    }
                }

                // Tamamlanmamış test varsa ve ekspertiz tamamlanmamışsa butonu göster
                if ($pendingTests && isset($expertiseDetails['status']) && $expertiseDetails['status'] != 'completed'):
                    ?>
                    <form method="POST" action="" class="mt-4">
                        <button type="submit" name="complete_all_tests" class="complete-all-tests-btn w-100">
                            <i class="fas fa-check-double"></i> TÜM TESTLERİ TAMAMLA
                        </button>
                    </form>
                <?php endif; ?>

                <!-- Fotoğraf Yükleme Bölümü -->
                <div class="expertise-card mt-4">
                    <div class="card-header-tab">
                        <span><i class="fas fa-camera me-2"></i> Araç Fotoğrafları</span>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12 mb-3">
                                <form action="upload_photos.php" method="POST" enctype="multipart/form-data" class="dropzone" id="expertisePhotosDropzone">
                                    <input type="hidden" name="expertise_id" value="<?php echo $expertiseId; ?>">
                                    <div class="fallback">
                                        <input name="file" type="file" multiple />
                                    </div>
                                    <div class="dz-message" data-dz-message>
                                        <div>
                                            <i class="fas fa-cloud-upload-alt fa-3x mb-3"></i>
                                            <h5>Fotoğrafları buraya sürükleyin veya tıklayarak seçin</h5>
                                            <p class="text-muted">En fazla 20 fotoğraf, her biri maksimum 10MB boyutunda</p>
                                        </div>
                                    </div>
                                </form>
                            </div>
                        </div>

                        <div class="row photo-gallery" id="photoGallery">
                            <!-- Fotoğraflar AJAX ile yüklenecek -->
                            <div class="col-12 text-center py-4">
                                <div class="spinner-border text-primary" role="status">
                                    <span class="visually-hidden">Yükleniyor...</span>
                                </div>
                                <p class="mt-2">Fotoğraflar yükleniyor...</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Toastr JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>
<!-- Dropzone JS -->
<script src="https://unpkg.com/dropzone@5/dist/min/dropzone.min.js"></script>

<!-- Custom JS -->
<script>
    // Toastr bildirim ayarları
    toastr.options = {
        "closeButton": true,
        "progressBar": true,
        "positionClass": "toast-top-right",
        "timeOut": "3000"
    };

    // Sidebar Toggle - sidebar.php içerisinde tanımlı elemanlar için
    $(document).ready(function() {
        if (document.getElementById('toggle-sidebar')) {
            document.getElementById('toggle-sidebar').addEventListener('click', function() {
                document.querySelector('.sidebar').classList.toggle('show');
            });
        }

        if (document.getElementById('sidebar-toggle')) {
            document.getElementById('sidebar-toggle').addEventListener('click', function() {
                document.querySelector('.sidebar').classList.remove('show');
            });
        }
    });

    // Dropzone konfigürasyonu
    Dropzone.autoDiscover = false;

    $(document).ready(function() {
        // Fotoğraf yükleme işlemi
        var myDropzone = new Dropzone("#expertisePhotosDropzone", {
            paramName: "file",
            maxFilesize: 10, // MB
            maxFiles: 20,
            acceptedFiles: "image/*",
            dictFallbackMessage: "Tarayıcınız sürükle-bırak dosya yüklemelerini desteklemiyor.",
            dictFileTooBig: "Dosya çok büyük ({{filesize}}MB). Maksimum dosya boyutu: {{maxFilesize}}MB.",
            dictInvalidFileType: "Bu dosya türünü yükleyemezsiniz.",
            dictResponseError: "Sunucu {{statusCode}} kodu ile yanıt verdi.",
            dictCancelUpload: "Yüklemeyi iptal et",
            dictCancelUploadConfirmation: "Bu yüklemeyi iptal etmek istediğinizden emin misiniz?",
            dictRemoveFile: "Dosyayı kaldır",
            dictMaxFilesExceeded: "Daha fazla dosya yükleyemezsiniz.",
            success: function(file, response) {
                // Başarılı yükleme sonrası galeriyi güncelle
                loadPhotos();
            }
        });

        // Sayfa yüklendiğinde fotoğrafları getir
        loadPhotos();

        // Fotoğrafları yükle
        function loadPhotos() {
            $.ajax({
                url: 'ajax/get_expertise_photos.php',
                type: 'GET',
                data: {
                    expertise_id: <?php echo $expertiseId; ?>
                },
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        // Galeriyi temizle ve fotoğrafları ekle
                        $('#photoGallery').empty();

                        if (response.photos && response.photos.length > 0) {
                            $.each(response.photos, function(i, photo) {
                                let photoHtml = `
                                <div class="col-lg-3 col-md-4 col-sm-6 mb-4">
                                    <div class="photo-thumbnail">
                                        <a href="${photo.image_url}" target="_blank" class="d-block">
                                            <img src="${photo.thumbnail_url}" class="img-fluid" alt="Araç Fotoğrafı">
                                        </a>
                                        <div class="photo-actions">
                                            <button class="btn btn-sm btn-danger delete-photo" data-photo-id="${photo.id}">
                                                <i class="fas fa-trash-alt"></i> Sil
                                            </button>
                                        </div>
                                    </div>
                                </div>
                                `;
                                $('#photoGallery').append(photoHtml);
                            });

                            // Fotoğraf silme işlemi
                            $('.delete-photo').on('click', function() {
                                const photoId = $(this).data('photo-id');
                                const photoCard = $(this).closest('.col-lg-3');

                                if (confirm('Bu fotoğrafı silmek istediğinizden emin misiniz?')) {
                                    $.ajax({
                                        url: 'ajax/delete_photo.php',
                                        type: 'POST',
                                        data: {
                                            photo_id: photoId
                                        },
                                        dataType: 'json',
                                        success: function(response) {
                                            if (response.success) {
                                                // Fotoğrafı galeriden kaldır
                                                photoCard.fadeOut(300, function() {
                                                    $(this).remove();
                                                    // Eğer hiç fotoğraf kalmadıysa mesaj göster
                                                    if ($('#photoGallery').children().length === 0) {
                                                        $('#photoGallery').html('<div class="col-12 text-center py-4">Henüz fotoğraf yüklenmemiş.</div>');
                                                    }
                                                });
                                                toastr.success('Fotoğraf başarıyla silindi');
                                            } else {
                                                toastr.error(response.message || 'Fotoğraf silinirken bir hata oluştu');
                                            }
                                        },
                                        error: function() {
                                            toastr.error('Sunucu hatası. Lütfen daha sonra tekrar deneyin.');
                                        }
                                    });
                                }
                            });
                        } else {
                            $('#photoGallery').html('<div class="col-12 text-center py-4">Henüz fotoğraf yüklenmemiş.</div>');
                        }
                    } else {
                        $('#photoGallery').html('<div class="col-12 text-center py-4">Fotoğraflar yüklenirken bir hata oluştu.</div>');
                    }
                },
                error: function() {
                    $('#photoGallery').html('<div class="col-12 text-center py-4">Sunucu hatası. Lütfen daha sonra tekrar deneyin.</div>');
                }
            });
        }
    });
</script>
</body>
</html>