<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// Sayfalama değişkenleri
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = isset($_GET['limit']) ? (int)$_GET['limit'] : 10;
$offset = ($page - 1) * $limit;

// Arama ve filtreleme değişkenleri
$search = isset($_GET['search']) ? trim($_GET['search']) : "";
$status = isset($_GET['status']) ? trim($_GET['status']) : "";
$sortBy = isset($_GET['sort_by']) ? trim($_GET['sort_by']) : "expertise_date";
$sortDir = isset($_GET['sort_dir']) ? trim($_GET['sort_dir']) : "DESC";

// Tarih formatı ayarları
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
date_default_timezone_set('Europe/Istanbul');

// Silme işlemi
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $expertiseId = (int)$_GET['id'];

    try {
        // Veritabanı bağlantısı
        $db = new Database();
        $conn = $db->getConnection();

        // Ekspertiz sınıfını başlat
        $expertise = new Expertise($conn);

        // Ekspertiz var mı kontrol et
        if ($expertise->readOne($expertiseId)) {
            // Kullanıcı yetkisi kontrol et
            if ($userRole == 'admin' || $userRole == 'manager' || $expertise->expert_id == $userId) {
                // Ekspertizi sil
                if ($expertise->delete()) {
                    // Başarılı mesajı
                    $successMessage = "Ekspertiz başarıyla silindi.";
                } else {
                    // Hata mesajı
                    $errorMessage = "Ekspertiz silinirken bir hata oluştu.";
                }
            } else {
                // Yetki hatası
                $errorMessage = "Bu işlem için yetkiniz bulunmamaktadır.";
            }
        } else {
            // Ekspertiz bulunamadı
            $errorMessage = "Ekspertiz bulunamadı.";
        }
    } catch (Exception $e) {
        // Hata durumunda
        $errorMessage = "Sistem hatası: " . $e->getMessage();
    }

    // Silme işleminden sonra ana listeye yönlendir
    header("Location: expertises.php" . ($search ? "?search=" . urlencode($search) : ""));
    exit;
}

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);

    // Ekspertizleri getir
    $expertises = $expertise->getExpertises($companyId, $limit, $offset, $search, $status, $sortBy, $sortDir);

    // Toplam ekspertiz sayısı
    $totalRecords = $expertise->countExpertises($companyId, $search, $status);

    // Toplam sayfa sayısı
    $totalPages = ceil($totalRecords / $limit);

    // Sayfa başlığı
    $pageTitle = "Ekspertizler";

    // Ekspertiz durumlarına göre istatistikler
    $statusCounts = $expertise->getExpertiseCountsByStatus($companyId);

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}

// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ekspertizler - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- SweetAlert2 -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sweetalert2@11.0.19/dist/sweetalert2.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">

    <?php include "includes/style.php"; ?>
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --success-color: #4cc9f0;
            --warning-color: #f72585;
            --danger-color: #e63946;
            --dark-color: #212529;
            --light-color: #f8f9fa;
            --sidebar-width: 250px;
            --topbar-height: 60px;
            --gradient-primary: linear-gradient(135deg, #4361ee 0%, #3a0ca3 100%);
            --shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);
            --shadow-md: 0 .5rem 1rem rgba(0, 0, 0, .15);
            --transition: all 0.3s ease;
        }

        /* Diğer CSS stilleri burada (dashboard.php ile aynı stiller) */
        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f9fafb;
            color: #333;
            overflow-x: hidden;
        }
    </style>
</head>
<body>
<!-- Sidebar -->
<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->
    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header d-flex justify-content-between align-items-center">
            <div>
                <h1 class="page-title">Ekspertizler</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                        <li class="breadcrumb-item active" aria-current="page">Ekspertizler</li>
                    </ol>
                </nav>
            </div>
            <div>
                <a href="expertise_add.php" class="btn btn-primary">
                    <i class="fas fa-plus me-2"></i> Yeni Ekspertiz
                </a>
            </div>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($successMessage)): ?>
            <div class="alert alert-success" role="alert">
                <i class="fas fa-check-circle me-2"></i> <?php echo $successMessage; ?>
            </div>
        <?php endif; ?>

        <!-- Filter Row -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="GET" action="expertises.php" class="row g-3">
                    <div class="col-md-4">
                        <div class="input-group">
                            <input type="text" class="form-control" placeholder="Arama..." name="search" value="<?php echo htmlspecialchars($search); ?>">
                            <button class="btn btn-primary" type="submit">
                                <i class="fas fa-search"></i>
                            </button>
                        </div>
                    </div>
                    <div class="col-md-3">
                        <select class="form-select" name="status" onchange="this.form.submit()">
                            <option value="">Tüm Durumlar</option>
                            <option value="pending" <?php echo $status == 'pending' ? 'selected' : ''; ?>>Bekliyor</option>
                            <option value="in_progress" <?php echo $status == 'in_progress' ? 'selected' : ''; ?>>Devam Ediyor</option>
                            <option value="completed" <?php echo $status == 'completed' ? 'selected' : ''; ?>>Tamamlandı</option>
                            <option value="cancelled" <?php echo $status == 'cancelled' ? 'selected' : ''; ?>>İptal Edildi</option>
                        </select>
                    </div>
                    <div class="col-md-3">
                        <select class="form-select" name="sort_by" onchange="this.form.submit()">
                            <option value="expertise_date" <?php echo $sortBy == 'expertise_date' ? 'selected' : ''; ?>>Tarih</option>
                            <option value="expertise_code" <?php echo $sortBy == 'expertise_code' ? 'selected' : ''; ?>>Ekspertiz Kodu</option>
                            <option value="customer_name" <?php echo $sortBy == 'customer_name' ? 'selected' : ''; ?>>Müşteri</option>
                            <option value="status" <?php echo $sortBy == 'status' ? 'selected' : ''; ?>>Durum</option>
                        </select>
                    </div>
                    <div class="col-md-2">
                        <select class="form-select" name="sort_dir" onchange="this.form.submit()">
                            <option value="DESC" <?php echo $sortDir == 'DESC' ? 'selected' : ''; ?>>Azalan</option>
                            <option value="ASC" <?php echo $sortDir == 'ASC' ? 'selected' : ''; ?>>Artan</option>
                        </select>
                    </div>
                </form>
            </div>
        </div>

        <!-- Stats Cards -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex align-items-center">
                            <div class="status-icon pending">
                                <i class="fas fa-clock"></i>
                            </div>
                            <div class="ms-3">
                                <h5 class="mb-0"><?php echo $statusCounts['pending']; ?></h5>
                                <p class="mb-0 text-muted">Bekleyen</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex align-items-center">
                            <div class="status-icon in_progress">
                                <i class="fas fa-cog fa-spin"></i>
                            </div>
                            <div class="ms-3">
                                <h5 class="mb-0"><?php echo $statusCounts['in_progress']; ?></h5>
                                <p class="mb-0 text-muted">Devam Eden</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex align-items-center">
                            <div class="status-icon completed">
                                <i class="fas fa-check"></i>
                            </div>
                            <div class="ms-3">
                                <h5 class="mb-0"><?php echo $statusCounts['completed']; ?></h5>
                                <p class="mb-0 text-muted">Tamamlanan</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card">
                    <div class="card-body">
                        <div class="d-flex align-items-center">
                            <div class="status-icon cancelled">
                                <i class="fas fa-times"></i>
                            </div>
                            <div class="ms-3">
                                <h5 class="mb-0"><?php echo $statusCounts['cancelled']; ?></h5>
                                <p class="mb-0 text-muted">İptal Edilen</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Expertises Table -->
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="card-title">Ekspertiz Listesi</h5>
                <div>
                    <button type="button" class="btn btn-sm btn-outline-primary" id="export-excel">
                        <i class="fas fa-file-excel me-1"></i> Excel
                    </button>
                    <button type="button" class="btn btn-sm btn-outline-danger" id="export-pdf">
                        <i class="fas fa-file-pdf me-1"></i> PDF
                    </button>
                </div>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-hover" id="expertises-table">
                        <thead>
                        <tr>
                            <th>Ekspertiz Kodu</th>
                            <th>Müşteri</th>
                            <th>Araç</th>
                            <th>Tarih</th>
                            <th>Eksper</th>
                            <th>Puan</th>
                            <th>Durum</th>
                            <th>İşlemler</th>
                        </tr>
                        </thead>
                        <tbody>
                        <?php if (!empty($expertises)): ?>
                            <?php foreach ($expertises as $exp): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($exp['expertise_code']); ?></td>
                                    <td>
                                        <div class="table-user">
                                            <div class="table-avatar">
                                                <?php echo strtoupper(substr($exp['customer_name'], 0, 1)); ?>
                                            </div>
                                            <span class="table-username"><?php echo htmlspecialchars($exp['customer_name']); ?></span>
                                        </div>
                                    </td>
                                    <td><?php echo htmlspecialchars($exp['vehicle_info']); ?></td>
                                    <td><?php echo date('d.m.Y H:i', strtotime($exp['expertise_date'])); ?></td>
                                    <td><?php echo htmlspecialchars($exp['expert_name']); ?></td>
                                    <td>
                                        <?php if ($exp['total_score']): ?>
                                            <div class="rating-pill">
                                                <?php echo number_format($exp['total_score'], 1); ?>
                                            </div>
                                        <?php else: ?>
                                            <span class="text-muted">-</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php
                                        $statusClass = '';
                                        switch ($exp['status']) {
                                            case 'pending':
                                                $statusClass = 'pending';
                                                $statusText = 'Bekliyor';
                                                break;
                                            case 'in_progress':
                                                $statusClass = 'in_progress';
                                                $statusText = 'Devam Ediyor';
                                                break;
                                            case 'completed':
                                                $statusClass = 'completed';
                                                $statusText = 'Tamamlandı';
                                                break;
                                            case 'cancelled':
                                                $statusClass = 'cancelled';
                                                $statusText = 'İptal Edildi';
                                                break;
                                            default:
                                                $statusClass = 'pending';
                                                $statusText = 'Bekliyor';
                                        }
                                        ?>
                                        <span class="status-badge <?php echo $statusClass; ?>"><?php echo $statusText; ?></span>
                                    </td>
                                    <td>
                                        <div class="d-flex">
                                            <a href="expertise_form.php?id=<?php echo $exp['id']; ?>" class="action-button me-1" title="Görüntüle">
                                                <i class="fas fa-eye"></i>
                                            </a>
                                            <a href="expertise_edit.php?id=<?php echo $exp['id']; ?>" class="action-button me-1" title="Düzenle">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="expertise_print.php?id=<?php echo $exp['id']; ?>" class="action-button me-1" title="Yazdır">
                                                <i class="fas fa-print"></i>
                                            </a>
                                            <button type="button" class="action-button delete-btn" title="Sil" data-id="<?php echo $exp['id']; ?>">
                                                <i class="fas fa-trash-alt"></i>
                                            </button>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="8" class="text-center">Ekspertiz kaydı bulunamadı</td>
                            </tr>
                        <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- Pagination -->
                <?php if ($totalPages > 1): ?>
                    <nav aria-label="Page navigation">
                        <ul class="pagination justify-content-center mt-4">
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=1<?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo '&sort_by=' . urlencode($sortBy) . '&sort_dir=' . urlencode($sortDir); ?>">
                                        <i class="fas fa-angle-double-left"></i>
                                    </a>
                                </li>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $page - 1; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo '&sort_by=' . urlencode($sortBy) . '&sort_dir=' . urlencode($sortDir); ?>">
                                        <i class="fas fa-angle-left"></i>
                                    </a>
                                </li>
                            <?php endif; ?>

                            <?php
                            $startPage = max(1, $page - 2);
                            $endPage = min($totalPages, $page + 2);

                            for ($i = $startPage; $i <= $endPage; $i++):
                                ?>
                                <li class="page-item <?php echo $i == $page ? 'active' : ''; ?>">
                                    <a class="page-link" href="?page=<?php echo $i; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo '&sort_by=' . urlencode($sortBy) . '&sort_dir=' . urlencode($sortDir); ?>"><?php echo $i; ?></a>
                                </li>
                            <?php endfor; ?>

                            <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $page + 1; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo '&sort_by=' . urlencode($sortBy) . '&sort_dir=' . urlencode($sortDir); ?>">
                                        <i class="fas fa-angle-right"></i>
                                    </a>
                                </li>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $totalPages; ?><?php echo $search ? '&search=' . urlencode($search) : ''; ?><?php echo $status ? '&status=' . urlencode($status) : ''; ?><?php echo '&sort_by=' . urlencode($sortBy) . '&sort_dir=' . urlencode($sortDir); ?>">
                                        <i class="fas fa-angle-double-right"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- SweetAlert2 -->
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11.0.19/dist/sweetalert2.min.js"></script>
<!-- SheetJS - Excel Export -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/xlsx/0.17.4/xlsx.full.min.js"></script>
<!-- jsPDF - PDF Export -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf/2.4.0/jspdf.umd.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/jspdf-autotable/3.5.20/jspdf.plugin.autotable.min.js"></script>

<!-- Custom JS -->
<script>
    // Sidebar Toggle
    document.getElementById('toggle-sidebar').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.toggle('show');
    });

    document.getElementById('sidebar-toggle').addEventListener('click', function() {
        document.querySelector('.sidebar').classList.remove('show');
    });

    // Delete Confirmation
    $('.delete-btn').on('click', function() {
        const id = $(this).data('id');

        Swal.fire({
            title: 'Emin misiniz?',
            text: "Bu ekspertiz kaydı silinecek. Bu işlem geri alınamaz!",
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#dc3545',
            cancelButtonColor: '#6c757d',
            confirmButtonText: 'Evet, sil!',
            cancelButtonText: 'İptal'
        }).then((result) => {
            if (result.isConfirmed) {
                window.location.href = `expertises.php?action=delete&id=${id}<?php echo $search ? '&search=' . urlencode($search) : ''; ?>`;
            }
        });
    });

    // Excel Export
    $('#export-excel').on('click', function() {
        const table = document.getElementById('expertises-table');
        const wb = XLSX.utils.table_to_book(table, {sheet: "Ekspertizler"});
        XLSX.writeFile(wb, 'ekspertizler_<?php echo date('Y-m-d'); ?>.xlsx');
    });

    // PDF Export
    $('#export-pdf').on('click', function() {
        const { jsPDF } = window.jspdf;
        const doc = new jsPDF();

        // Header
        doc.setFontSize(18);
        doc.text('Ekspertiz Listesi', 14, 22);
        doc.setFontSize(11);
        doc.text('Tarih: <?php echo date('d.m.Y'); ?>', 14, 30);

        // Table
        doc.autoTable({
            html: '#expertises-table',
            startY: 35,
            styles: {
                fontSize: 9,
                cellPadding: 3
            },
            columnStyles: {
                0: {cellWidth: 30},
                1: {cellWidth: 30},
                2: {cellWidth: 30},
                3: {cellWidth: 25},
                4: {cellWidth: 25},
                5: {cellWidth: 15},
                6: {cellWidth: 25}
            },
            // İşlemler sütununu hariç tutma
            columns: [
                {header: 'Ekspertiz Kodu', dataKey: 0},
                {header: 'Müşteri', dataKey: 1},
                {header: 'Araç', dataKey: 2},
                {header: 'Tarih', dataKey: 3},
                {header: 'Eksper', dataKey: 4},
                {header: 'Puan', dataKey: 5},
                {header: 'Durum', dataKey: 6}
            ]
        });

        // Footer
        const pageCount = doc.internal.getNumberOfPages();
        for (let i = 1; i <= pageCount; i++) {
            doc.setPage(i);
            doc.setFontSize(8);
            doc.text('Sayfa ' + i + ' / ' + pageCount, doc.internal.pageSize.width - 30, doc.internal.pageSize.height - 10);
            doc.text('Araç Ekspertiz Sistemi', 14, doc.internal.pageSize.height - 10);
        }

        doc.save('ekspertizler_<?php echo date('Y-m-d'); ?>.pdf');
    });
</script>
</body>
</html>