<style>
    :root {
        --primary-color: #4361ee;
        --secondary-color: #3f37c9;
        --accent-color: #4895ef;
        --success-color: #4cc9f0;
        --warning-color: #f72585;
        --danger-color: #e63946;
        --dark-color: #212529;
        --light-color: #f8f9fa;
        --sidebar-width: 250px;
        --topbar-height: 60px;
        --gradient-primary: linear-gradient(135deg, #4361ee 0%, #3a0ca3 100%);
        --shadow-sm: 0 .125rem .25rem rgba(0, 0, 0, .075);
        --shadow-md: 0 .5rem 1rem rgba(0, 0, 0, .15);
        --transition: all 0.3s ease;
    }

    * {
        margin: 0;
        padding: 0;
        box-sizing: border-box;
    }

    body {
        font-family: 'Poppins', sans-serif;
        background-color: #f9fafb;
        color: #333;
        overflow-x: hidden;
    }

    /* Sidebar */
    .sidebar {
        position: fixed;
        top: 0;
        left: 0;
        width: var(--sidebar-width);
        height: 100vh;
        background: white;
        border-right: 1px solid rgba(0, 0, 0, 0.05);
        box-shadow: var(--shadow-sm);
        z-index: 1000;
        transition: var(--transition);
        overflow-y: auto;
    }

    .sidebar-logo {
        display: flex;
        align-items: center;
        padding: 1rem;
        height: var(--topbar-height);
        border-bottom: 1px solid rgba(0, 0, 0, 0.05);
    }

    .sidebar-logo-icon {
        width: 35px;
        height: 35px;
        display: flex;
        align-items: center;
        justify-content: center;
        background: var(--gradient-primary);
        border-radius: 8px;
        margin-right: 0.8rem;
    }

    .sidebar-logo-icon i {
        color: white;
        font-size: 1.2rem;
    }

    .sidebar-logo-text h1 {
        font-size: 1.2rem;
        font-weight: 600;
        margin-bottom: 0;
        color: var(--dark-color);
    }

    .sidebar-logo-text p {
        font-size: 0.7rem;
        color: #6c757d;
        margin-bottom: 0;
    }

    .sidebar-toggle {
        display: none;
        background: transparent;
        border: none;
        font-size: 1.2rem;
        cursor: pointer;
        color: #6c757d;
    }

    .nav-menu {
        padding: 1rem 0;
    }

    .nav-heading {
        font-size: 0.8rem;
        font-weight: 600;
        text-transform: uppercase;
        color: #6c757d;
        padding: 0.5rem 1.5rem;
        margin-top: 1rem;
    }

    .nav-item {
        position: relative;
    }

    .nav-link {
        display: flex;
        align-items: center;
        padding: 0.6rem 1.5rem;
        color: #6c757d;
        text-decoration: none;
        font-size: 0.9rem;
        font-weight: 500;
        transition: var(--transition);
    }

    .nav-link i {
        font-size: 1.1rem;
        margin-right: 0.8rem;
        width: 20px;
        text-align: center;
    }

    .nav-link.active {
        color: var(--primary-color);
        background-color: rgba(67, 97, 238, 0.1);
        font-weight: 600;
    }

    .nav-link:hover {
        color: var(--primary-color);
        background-color: rgba(67, 97, 238, 0.05);
    }

    .nav-link.active::after {
        content: '';
        position: absolute;
        right: 0;
        top: 50%;
        transform: translateY(-50%);
        width: 4px;
        height: 20px;
        background: var(--primary-color);
        border-radius: 2px 0 0 2px;
    }

    .main-content {
        margin-left: var(--sidebar-width);
        min-height: 100vh;
        transition: var(--transition);
    }

    /* Topbar */
    .topbar {
        height: var(--topbar-height);
        background: white;
        border-bottom: 1px solid rgba(0, 0, 0, 0.05);
        display: flex;
        align-items: center;
        padding: 0 1.5rem;
        position: sticky;
        top: 0;
        z-index: 999;
        box-shadow: var(--shadow-sm);
    }

    .toggle-sidebar {
        background: transparent;
        border: none;
        font-size: 1.2rem;
        cursor: pointer;
        color: #6c757d;
        margin-right: 1rem;
        display: none;
    }

    .topbar-title {
        font-size: 1.2rem;
        font-weight: 600;
        color: var(--dark-color);
        margin-right: auto;
    }

    .topbar-actions {
        display: flex;
        align-items: center;
    }

    .topbar-action {
        width: 35px;
        height: 35px;
        display: flex;
        align-items: center;
        justify-content: center;
        border-radius: 50%;
        cursor: pointer;
        color: #6c757d;
        margin-left: 0.5rem;
        transition: var(--transition);
        position: relative;
    }

    .topbar-action:hover {
        background-color: rgba(0, 0, 0, 0.05);
        color: var(--primary-color);
    }

    .topbar-action-badge {
        position: absolute;
        top: -5px;
        right: -5px;
        width: 16px;
        height: 16px;
        border-radius: 50%;
        background-color: var(--danger-color);
        color: white;
        font-size: 0.65rem;
        display: flex;
        align-items: center;
        justify-content: center;
    }

    .user-dropdown {
        display: flex;
        align-items: center;
        padding: 0 0.5rem;
        margin-left: 1rem;
        cursor: pointer;
        position: relative;
    }

    .user-avatar {
        width: 35px;
        height: 35px;
        border-radius: 50%;
        background: var(--gradient-primary);
        color: white;
        font-weight: 600;
        display: flex;
        align-items: center;
        justify-content: center;
        margin-right: 0.8rem;
    }

    .user-info {
        display: none;
    }

    .user-name {
        font-size: 0.9rem;
        font-weight: 600;
        color: var(--dark-color);
        margin-bottom: 0;
    }

    .user-role {
        font-size: 0.75rem;
        color: #6c757d;
        margin-bottom: 0;
    }

    .dropdown-toggle::after {
        margin-left: 0.5rem;
    }

    /* Content */
    .content {
        padding: 1.5rem;
    }

    .page-header {
        margin-bottom: 1.5rem;
    }

    .page-title {
        font-size: 1.5rem;
        font-weight: 600;
        color: var(--dark-color);
        margin-bottom: 0.5rem;
    }

    .breadcrumb {
        font-size: 0.85rem;
    }

    .card {
        background: white;
        border: none;
        border-radius: 10px;
        box-shadow: var(--shadow-sm);
        margin-bottom: 1.5rem;
        transition: var(--transition);
    }

    .card:hover {
        transform: translateY(-3px);
        box-shadow: var(--shadow-md);
    }

    .card-header {
        background: transparent;
        border-bottom: 1px solid rgba(0, 0, 0, 0.05);
        padding: 1rem 1.5rem;
    }

    .card-title {
        font-size: 1rem;
        font-weight: 600;
        color: var(--dark-color);
        margin-bottom: 0;
    }

    .card-body {
        padding: 1.5rem;
    }

    /* Stats Cards */
    .stats-card {
        display: flex;
        align-items: center;
    }

    .stats-icon {
        width: 50px;
        height: 50px;
        border-radius: 10px;
        display: flex;
        align-items: center;
        justify-content: center;
        margin-right: 1rem;
        font-size: 1.5rem;
    }

    .stats-icon.primary {
        background-color: rgba(67, 97, 238, 0.1);
        color: var(--primary-color);
    }

    .stats-icon.success {
        background-color: rgba(76, 201, 240, 0.1);
        color: var(--success-color);
    }

    .stats-icon.warning {
        background-color: rgba(247, 37, 133, 0.1);
        color: var(--warning-color);
    }

    .stats-icon.danger {
        background-color: rgba(230, 57, 70, 0.1);
        color: var(--danger-color);
    }

    .stats-info h3 {
        font-size: 1.5rem;
        font-weight: 700;
        color: var(--dark-color);
        margin-bottom: 0.3rem;
    }

    .stats-info p {
        font-size: 0.85rem;
        color: #6c757d;
        margin-bottom: 0;
    }

    .stats-change {
        font-size: 0.8rem;
        font-weight: 500;
        margin-top: 0.3rem;
    }

    .stats-change.up {
        color: #10b981;
    }

    .stats-change.down {
        color: #ef4444;
    }

    /* Tables */
    .table {
        color: #6c757d;
    }

    .table th {
        font-weight: 600;
        border-top: none;
        border-bottom-width: 1px;
        color: var(--dark-color);
        font-size: 0.85rem;
        text-transform: uppercase;
    }

    .table td {
        vertical-align: middle;
        font-size: 0.9rem;
    }

    .table-user {
        display: flex;
        align-items: center;
    }

    .table-avatar {
        width: 30px;
        height: 30px;
        border-radius: 50%;
        margin-right: 0.8rem;
        background: #e9ecef;
        display: flex;
        align-items: center;
        justify-content: center;
        color: #6c757d;
        font-size: 0.8rem;
        font-weight: 600;
    }

    .table-username {
        font-weight: 500;
        color: var(--dark-color);
    }

    .status-badge {
        padding: 0.25rem 0.6rem;
        font-size: 0.75rem;
        font-weight: 500;
        border-radius: 20px;
    }

    .status-badge.pending {
        background-color: rgba(234, 179, 8, 0.1);
        color: #eab308;
    }

    .status-badge.in_progress {
        background-color: rgba(67, 97, 238, 0.1);
        color: var(--primary-color);
    }

    .status-badge.completed {
        background-color: rgba(16, 185, 129, 0.1);
        color: #10b981;
    }

    .status-badge.cancelled {
        background-color: rgba(239, 68, 68, 0.1);
        color: #ef4444;
    }

    /* Charts */
    .chart-container {
        width: 100%;
        height: 300px;
    }

    /* Actions */
    .action-button {
        width: 30px;
        height: 30px;
        border-radius: 50%;
        background-color: rgba(0, 0, 0, 0.05);
        color: #6c757d;
        display: flex;
        align-items: center;
        justify-content: center;
        font-size: 0.85rem;
        transition: var(--transition);
        cursor: pointer;
        border: none;
    }

    .action-button:hover {
        background-color: rgba(67, 97, 238, 0.1);
        color: var(--primary-color);
    }

    /* Responsive */
    @media (max-width: 992px) {
        .sidebar {
            left: calc(-1 * var(--sidebar-width));
        }

        .sidebar.show {
            left: 0;
        }

        .main-content {
            margin-left: 0;
        }

        .toggle-sidebar {
            display: block;
        }

        .sidebar-toggle {
            display: flex;
            align-items: center;
            justify-content: center;
            margin-left: auto;
        }

        .user-info {
            display: none;
        }
    }

    @media (min-width: 992px) {
        .user-info {
            display: block;
        }
    }

    @media (max-width: 576px) {
        .topbar {
            padding: 0 1rem;
        }

        .content {
            padding: 1rem;
        }

        .topbar-title {
            font-size: 1rem;
        }

        .page-title {
            font-size: 1.2rem;
        }

        .card-body {
            padding: 1rem;
        }
    }
</style>