$(document).ready(function() {
    // Animasyon gecikmesi için değişkenler
    var animationDelay = 100;

    // Sayfa yüklendiğinde animasyonları başlat
    function startAnimations() {
        $('.fade-in-down, .fade-in-up, .fade-in-left, .fade-in-right').each(function() {
            var $element = $(this);
            var delay = $element.css('animation-delay') ? parseFloat($element.css('animation-delay')) * 1000 : 0;

            setTimeout(function() {
                $element.css('visibility', 'visible');
            }, delay);
        });
    }

    // Animasyonları başlat
    startAnimations();

    // Şifre göster/gizle işlevi
    $("#toggle-password").click(function() {
        const passwordField = $("#password");
        const eyeIcon = $("#eye-icon");

        if (passwordField.attr("type") === "password") {
            passwordField.attr("type", "text");
            eyeIcon.removeClass("fa-eye").addClass("fa-eye-slash");
        } else {
            passwordField.attr("type", "password");
            eyeIcon.removeClass("fa-eye-slash").addClass("fa-eye");
        }
    });

    // Input alanlarına odaklanma efektleri
    $(".form-control").focus(function() {
        $(this).parent().addClass("focused");
    }).blur(function() {
        $(this).parent().removeClass("focused");
    });

    // Şifremi unuttum işlevi
    $("#forgot-password").click(function(e) {
        e.preventDefault();

        // Modal gösterme veya sayfa yönlendirme
        Swal.fire({
            title: 'Şifre Sıfırlama',
            text: 'Şifre sıfırlama bağlantısı için e-posta adresinizi girin',
            input: 'email',
            inputPlaceholder: 'E-posta adresinizi girin',
            showCancelButton: true,
            confirmButtonText: 'Gönder',
            cancelButtonText: 'İptal',
            confirmButtonColor: '#4361ee',
            showLoaderOnConfirm: true,
            backdrop: true,
            preConfirm: (email) => {
                return new Promise((resolve) => {
                    // AJAX ile şifre sıfırlama
                    setTimeout(() => {
                        $.ajax({
                            type: "POST",
                            url: "forgot_password.php",
                            data: {
                                email: email
                            },
                            dataType: "json",
                            success: function(response) {
                                if (response.success) {
                                    resolve(response);
                                } else {
                                    Swal.showValidationMessage(response.message);
                                }
                            },
                            error: function() {
                                Swal.showValidationMessage('Sunucu hatası! Lütfen daha sonra tekrar deneyiniz.');
                            }
                        });
                    }, 1000);
                });
            },
            allowOutsideClick: () => !Swal.isLoading()
        }).then((result) => {
            if (result.isConfirmed) {
                Swal.fire({
                    title: 'Başarılı!',
                    text: 'Şifre sıfırlama bağlantısı e-posta adresinize gönderildi.',
                    icon: 'success',
                    confirmButtonColor: '#4361ee'
                });
            }
        });
    });

    // Kayıt olma işlevi
    $("#register-link").click(function(e) {
        e.preventDefault();

        // Kayıt sayfasına yönlendirme veya modal gösterme
        window.location.href = "register.php";
    });

    // Sosyal medya butonları
    $(".social-btn").click(function() {
        var socialType = "";

        if ($(this).hasClass("google")) {
            socialType = "google";
        } else if ($(this).hasClass("facebook")) {
            socialType = "facebook";
        } else if ($(this).hasClass("apple")) {
            socialType = "apple";
        }

        // İlgili sosyal medya girişi için yönlendirme
        window.location.href = "social_login.php?type=" + socialType;
    });

    // Giriş formu gönderme işlevi
    $("#login-form").submit(function(e) {
        e.preventDefault();

        // Form verilerini alma
        const username = $("#username").val();
        const password = $("#password").val();
        const rememberMe = $("#remember-me").is(":checked");

        // Form doğrulama
        if (!username || !password) {
            $("#error-message").text("Lütfen kullanıcı adı ve şifre giriniz.");
            $("#login-error").fadeIn().delay(3000).fadeOut();
            return false;
        }

        // Giriş butonunu devre dışı bırakma ve spinner gösterme
        $("#login-button").prop("disabled", true);
        $("#login-spinner").show();

        // AJAX ile giriş işlemi
        $.ajax({
            type: "POST",
            url: "apix/login_process.php",
            data: {
                username: username,
                password: password,
                remember: rememberMe
            },
            dataType: "json",
            success: function(response) {
                // Başarılı giriş
                if (response.success) {
                    // Başarılı giriş animasyonu
                    Swal.fire({
                        title: 'Giriş Başarılı!',
                        text: 'Yönlendiriliyorsunuz...',
                        icon: 'success',
                        timer: 1500,
                        timerProgressBar: true,
                        showConfirmButton: false,
                        willClose: () => {
                            // "Beni hatırla" seçili ise, localStorage'a kaydetme
                            if (rememberMe) {
                                localStorage.setItem("rememberedUser", JSON.stringify({
                                    username: username,
                                    remember: true
                                }));
                            } else {
                                localStorage.removeItem("rememberedUser");
                            }

                            // Dashboard sayfasına yönlendirme
                            window.location.href = response.redirect_url;
                        }
                    });
                } else {
                    // Hata mesajını gösterme
                    $("#error-message").text(response.message);
                    $("#login-error").fadeIn().delay(3000).fadeOut();

                    // Hata animasyonu
                    $("#login-form").addClass("animate__animated animate__shakeX");
                    setTimeout(function() {
                        $("#login-form").removeClass("animate__animated animate__shakeX");
                    }, 1000);
                }
            },
            error: function() {
                // Sunucu hatası
                $("#error-message").text("Sunucu hatası! Lütfen daha sonra tekrar deneyiniz.");
                $("#login-error").fadeIn().delay(3000).fadeOut();
            },
            complete: function() {
                // İşlem tamamlandığında butonları tekrar aktif etme ve spinner gizleme
                $("#login-button").prop("disabled", false);
                $("#login-spinner").hide();
            }
        });
    });

    // Sayfa yüklendiğinde kullanıcı adı alanına odaklanma
    $("#username").focus();

    // Daha önce kaydedilmiş kullanıcı bilgilerini kontrol etme (localStorage)
    if (localStorage.getItem("rememberedUser")) {
        const userData = JSON.parse(localStorage.getItem("rememberedUser"));
        $("#username").val(userData.username);
        $("#remember-me").prop("checked", true);
    }

    // SweetAlert2 kütüphanesini kontrol etme ve gerekirse yükleme
    if (typeof Swal === 'undefined') {
        var sweetAlertScript = document.createElement('script');
        sweetAlertScript.src = 'https://cdn.jsdelivr.net/npm/sweetalert2@11';
        document.head.appendChild(sweetAlertScript);
    }

    // Sayfanın yüklenmesini takip etme ve yükleme animasyonu gösterme
    $(window).on('load', function() {
        $(".preloader").fadeOut(500);
    });

    // İletişim formu gönderimi (varsa)
    $("#contact-form").submit(function(e) {
        e.preventDefault();
        // İletişim formu Ajax işlemi...
    });
});