<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';
require_once 'classes/KaportaTest.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// ID parametresi kontrol
if (!isset($_GET['expertise_id']) || !is_numeric($_GET['expertise_id'])) {
    header("Location: expertises.php");
    exit;
}

$expertiseId = (int)$_GET['expertise_id'];

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $kaportaTest = new KaportaTest($conn);

    // Ekspertiz detaylarını getir
    $expertiseDetails = $expertise->readOne($expertiseId);

    // Ekspertiz bulunamadıysa veya başka şirkete aitse reddet
    if (!$expertiseDetails || $expertiseDetails['company_id'] != $companyId) {
        header("Location: expertises.php");
        exit;
    }

    // Araç bilgilerini getir
    $vehicleDetails = $vehicle->readOne($expertiseDetails['vehicle_id']);

    // Kaporta testi verilerini getir
    $kaportaTestData = $kaportaTest->readByExpertiseId($expertiseId);

    // Varsayılan veriler
    $drawing_data = '';
    $notes = '';

    if ($kaportaTestData) {
        $drawing_data = $kaportaTestData['drawing_data'];
        $notes = $kaportaTestData['notes'];
    }

    // Form gönderildiğinde
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        if (isset($_POST['save_kaporta_test'])) {
            // Form verilerini al
            $drawing_data = $_POST['drawing_data'] ?? '';
            $notes = $_POST['kaporta_notes'] ?? '';

            // Kaporta testi nesnesini oluştur
            $kaportaTest->expertise_id = $expertiseId;
            $kaportaTest->vehicle_id = $expertiseDetails['vehicle_id'];
            $kaportaTest->drawing_data = $drawing_data;
            $kaportaTest->notes = $notes;

            // Verileri kaydet
            if ($kaportaTest->saveOrUpdate()) {
                // Ekspertiz durumunu güncelle
                if (isset($_POST['complete_test']) && $_POST['complete_test'] == 1) {
                    // Kaporta testi tamamlandı olarak işaretle
                    $extraData = json_decode($expertiseDetails['extra_data'] ?? '{}', true);
                    if (!is_array($extraData)) $extraData = [];

                    if (!isset($extraData['tests'])) $extraData['tests'] = [];
                    $extraData['tests']['kaporta_test'] = 2; // 2 = Tamamlandı

                    $expertise->id = $expertiseId;
                    $expertise->extra_data = json_encode($extraData);
                    $expertise->updateExtraData();
                }

                $successMessage = "Kaporta testi başarıyla kaydedildi.";

                // Sayfayı yenile
                header("Location: kaporta_test.php?expertise_id=" . $expertiseId . "&success=" . urlencode($successMessage));
                exit;
            } else {
                $errorMessage = "Kaporta testi kaydedilirken bir hata oluştu.";
            }
        }
    }

    // Success mesajı
    if (isset($_GET['success'])) {
        $successMessage = $_GET['success'];
    }

    // Sayfa başlığı
    $pageTitle = "Kaporta Testi - " . $expertiseDetails['expertise_code'];

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}
// Ekspertiz extra data'sını decode et
$extraData = isset($expertiseDetails['extra_data']) && !empty($expertiseDetails['extra_data'])
    ? json_decode($expertiseDetails['extra_data'], true)
    : [];

$vehicleType = isset($extraData['vehicle_type']) ? $extraData['vehicle_type'] : 'normal';

$vehicleTypeImages = [
    'normal' => 'normal.png',
    'hatchback' => 'hatchback.png',
    'suv' => 'suv.png',
    'panelvan' => 'panelvan.png',
    'kamyonet1' => 'kamyonet1.png',
    'kamyonet2' => 'kamyonet2.png',
    'sedan' => 'sedan.png',
    'hb' => 'hb.png',
    'kombi' => 'kombi.png'
];
// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- Toastr Bildirimler için -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">

    <?php include "includes/style.php"; ?>
    <style>
        .kaporta-container {
            position: relative;
            width: 100%;
            max-width: 800px;
            margin: 0 auto;
        }

        .kaporta-canvas {
            border: 1px solid #ccc;
            background-color: #fff;
            display: block;
            margin: 0 auto;
        }

        .tool-panel {
            background: #f8f9fa;
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 20px;
        }

        .color-picker {
            width: 40px;
            height: 40px;
            padding: 0;
            border: none;
            cursor: pointer;
        }

        .line-width {
            width: 100%;
        }

        .tool-button {
            width: 40px;
            height: 40px;
            padding: 0;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            margin-right: 5px;
        }

        .sticky-buttons {
            position: sticky;
            bottom: 0;
            background-color: #fff;
            padding: 1rem 0;
            box-shadow: 0 -4px 6px -1px rgba(0, 0, 0, 0.1);
            z-index: 1000;
            border-top: 1px solid #e9ecef;
        }
    </style>
</head>
<body>
<!-- Sidebar -->
<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->
    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header d-flex justify-content-between align-items-center">
            <div>
                <h1 class="page-title">Kaporta Testi</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                        <li class="breadcrumb-item"><a href="expertises.php">Ekspertizler</a></li>
                        <li class="breadcrumb-item"><a href="expertise_form.php?id=<?php echo $expertiseId; ?>"><?php echo htmlspecialchars($expertiseDetails['expertise_code']); ?></a></li>
                        <li class="breadcrumb-item active" aria-current="page">Kaporta Testi</li>
                    </ol>
                </nav>
            </div>
            <div>
                <a href="expertise_form.php?id=<?php echo $expertiseId; ?>" class="btn btn-secondary">
                    <i class="fas fa-arrow-left me-2"></i> Geri Dön
                </a>
            </div>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($successMessage)): ?>
            <div class="alert alert-success" role="alert">
                <i class="fas fa-check-circle me-2"></i> <?php echo $successMessage; ?>
            </div>
        <?php endif; ?>

        <!-- Araç Bilgileri Özeti -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title mb-0"><i class="fas fa-car me-2"></i> Araç Bilgileri</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Plaka:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['plate_number']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Marka/Model:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['brand_name'] . ' ' . $vehicleDetails['model_name']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Yıl:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['year']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Ekspertiz Kodu:</strong></p>
                        <p><?php echo htmlspecialchars($expertiseDetails['expertise_code']); ?></p>
                    </div>
                </div>
            </div>
        </div>

        <!-- Kaporta Testi Formu -->
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0"><i class="fas fa-car-crash me-2"></i> Kaporta Testi</h5>
            </div>
            <div class="card-body">
                <form id="kaportaForm" action="" method="POST">
                    <!-- Çizim Araçları -->
                    <div class="tool-panel">
                        <div class="row">
                            <div class="col-md-4">
                                <label class="form-label">Araçlar:</label>
                                <div class="btn-group mb-2" role="group">
                                    <button type="button" class="btn btn-outline-primary tool-button" data-tool="brush" title="Fırça">
                                        <i class="fas fa-paint-brush"></i>
                                    </button>
                                    <button type="button" class="btn btn-outline-primary tool-button" data-tool="rect" title="Dikdörtgen">
                                        <i class="fas fa-square"></i>
                                    </button>
                                    <button type="button" class="btn btn-outline-primary tool-button" data-tool="circle" title="Daire">
                                        <i class="fas fa-circle"></i>
                                    </button>
                                    <button type="button" class="btn btn-outline-primary tool-button" data-tool="text" title="Yazı">
                                        <i class="fas fa-font"></i>
                                    </button>
                                    <button type="button" class="btn btn-outline-primary tool-button" data-tool="eraser" title="Silgi">
                                        <i class="fas fa-eraser"></i>
                                    </button>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <label class="form-label">Renk:</label>
                                <div class="d-flex mb-2">
                                    <input type="color" class="color-picker me-2" value="#ff0000">
                                    <button type="button" class="btn btn-danger btn-sm me-1" data-color="#ff0000"></button>
                                    <button type="button" class="btn btn-warning btn-sm me-1" data-color="#ffa500"></button>
                                    <button type="button" class="btn btn-success btn-sm me-1" data-color="#00ff00"></button>
                                    <button type="button" class="btn btn-info btn-sm me-1" data-color="#00ffff"></button>
                                    <button type="button" class="btn btn-primary btn-sm me-1" data-color="#0000ff"></button>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <label class="form-label">Kalınlık: <span id="widthValue">5</span>px</label>
                                <input type="range" class="form-range line-width" min="1" max="20" value="5">
                            </div>
                        </div>
                        <div class="row mt-2">
                            <div class="col-md-12">
                                <button type="button" class="btn btn-danger btn-sm me-2" id="clearCanvas">
                                    <i class="fas fa-trash me-1"></i> Temizle
                                </button>
                                <button type="button" class="btn btn-secondary btn-sm" id="undoAction">
                                    <i class="fas fa-undo me-1"></i> Geri Al
                                </button>
                            </div>
                        </div>
                    </div>

                    <!-- Kaporta Çizim Alanı -->
                    <div class="kaporta-container">
                        <canvas id="kaportaCanvas" class="kaporta-canvas" width="800" height="600"></canvas>
                    </div>

                    <!-- Notlar -->
                    <!-- Gizli Input - Canvas Verileri -->
                    <input type="hidden" name="drawing_data" id="drawingData" value="<?php echo htmlspecialchars($drawing_data); ?>">

                    <!-- Notlar -->
                    <div class="form-group mt-4">
                        <label for="kaportaNotes" class="form-label">Kaporta Testi Notları:</label>
                        <textarea class="form-control" id="kaportaNotes" name="kaporta_notes" rows="4"><?php echo htmlspecialchars($notes); ?></textarea>
                    </div>

                    <!-- Gizli Input - Canvas Verileri -->
                    <input type="hidden" name="kaporta_data" id="kaportaData" value="<?php echo htmlspecialchars(json_encode($kaporta_data)); ?>">

                    <!-- Kaydet Butonları -->
                    <div class="sticky-buttons">
                        <div class="row">
                            <div class="col-md-6">
                                <button type="submit" class="btn btn-primary w-100" name="save_kaporta_test">
                                    <i class="fas fa-save me-2"></i> Kaydet
                                </button>
                            </div>
                            <div class="col-md-6">
                                <button type="submit" class="btn btn-success w-100" name="save_kaporta_test" value="1">
                                    <i class="fas fa-check-circle me-2"></i> Kaydet ve Testi Tamamla
                                </button>
                                <input type="hidden" name="complete_test" id="completeTest" value="0">
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Toastr JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>

<!-- Custom JS -->
<script>
    // Toastr ayarları
    toastr.options = {
        "closeButton": true,
        "progressBar": true,
        "positionClass": "toast-top-right",
        "timeOut": "3000"
    };

    // Canvas işlemleri
    // Canvas işlemleri
    document.addEventListener('DOMContentLoaded', function() {
        const canvas = document.getElementById('kaportaCanvas');
        const ctx = canvas.getContext('2d');
        const form = document.getElementById('kaportaForm');
        const drawingDataInput = document.getElementById('drawingData');
        const completeTestInput = document.getElementById('completeTest');

        // Varsayılan değerler
        let currentTool = 'brush';
        let currentColor = '#ff0000';
        let currentWidth = 5;
        let isDrawing = false;
        let startX = 0;
        let startY = 0;
        let lastX = 0;
        let lastY = 0;
        let textInput = '';

        // Tüm çizimleri saklayacak dizi - Önemli: Bu değişken tanımlanmalı
        let allDrawings = [];

        // Çizim geçmişi
        let drawHistory = [];
        let currentStep = -1;

        // Araba resmi yükleme
        const carImage = new Image();
        carImage.src = 'assets/images/car_types/<?php echo isset($vehicleTypeImages[$vehicleType]) ? $vehicleTypeImages[$vehicleType] : 'normal.png'; ?>'; // Araç şeması görseli

        carImage.onload = function() {
            // Canvas'ı temizle ve araba resmini çiz
            ctx.clearRect(0, 0, canvas.width, canvas.height);
            ctx.drawImage(carImage, 0, 0, canvas.width, canvas.height);

            // Önceden kaydedilmiş çizimler varsa yükle
            loadSavedData();

            // Çizim geçmişine ilk durumu ekle
            saveState();
        };

        // Önceden kaydedilmiş verileri yükleme
        function loadSavedData() {
            try {
                const savedData = drawingDataInput.value;
                if (savedData && savedData.trim() !== '') {
                    // Kaydedilmiş çizimleri diziye yükle
                    allDrawings = JSON.parse(savedData);

                    // Kaydedilmiş çizimleri yeniden çiz
                    allDrawings.forEach(drawing => {
                        switch(drawing.type) {
                            case 'brush':
                                drawBrushStroke(drawing.points, drawing.color, drawing.width);
                                break;
                            case 'rect':
                                drawRect(drawing.x, drawing.y, drawing.width, drawing.height, drawing.color, drawing.lineWidth);
                                break;
                            case 'circle':
                                drawCircle(drawing.x, drawing.y, drawing.radius, drawing.color, drawing.lineWidth);
                                break;
                            case 'text':
                                drawText(drawing.x, drawing.y, drawing.text, drawing.color, drawing.fontSize);
                                break;
                        }
                    });
                }
            } catch(e) {
                console.error('Kaydedilmiş veri yüklenemedi:', e);
                // Hata durumunda boş dizi oluştur
                allDrawings = [];
            }
        }

        // Durumu kaydetme (geçmiş için)
        function saveState() {
            // Canvas'ın mevcut halini kaydet
            const imageData = ctx.getImageData(0, 0, canvas.width, canvas.height);

            // Eğer geri aldıysak, sonraki adımları sil
            if (currentStep < drawHistory.length - 1) {
                drawHistory = drawHistory.slice(0, currentStep + 1);
            }

            drawHistory.push(imageData);
            currentStep = drawHistory.length - 1;
        }

        // Geri alma işlemi
        function undo() {
            if (currentStep > 0) {
                currentStep--;
                ctx.putImageData(drawHistory[currentStep], 0, 0);

                // Çizim listesini güncelle
                if (allDrawings.length > 0) {
                    allDrawings.pop();
                }
            }
        }

        // Fırça işlevi
        function drawBrushStroke(points, color, width) {
            ctx.strokeStyle = color;
            ctx.lineWidth = width;
            ctx.lineJoin = 'round';
            ctx.lineCap = 'round';

            ctx.beginPath();
            if (points && points.length > 0) {
                ctx.moveTo(points[0].x, points[0].y);

                for (let i = 1; i < points.length; i++) {
                    ctx.lineTo(points[i].x, points[i].y);
                }
            }

            ctx.stroke();
        }

        // Dikdörtgen çizme
        function drawRect(x, y, width, height, color, lineWidth) {
            ctx.strokeStyle = color;
            ctx.lineWidth = lineWidth;
            ctx.strokeRect(x, y, width, height);
        }

        // Daire çizme
        function drawCircle(x, y, radius, color, lineWidth) {
            ctx.strokeStyle = color;
            ctx.lineWidth = lineWidth;
            ctx.beginPath();
            ctx.arc(x, y, radius, 0, Math.PI * 2);
            ctx.stroke();
        }

        // Yazı yazma
        function drawText(x, y, text, color, fontSize) {
            ctx.fillStyle = color;
            ctx.font = `${fontSize}px Arial`;
            ctx.fillText(text, x, y);
        }

        // Çizim noktaları
        let currentBrushPoints = [];

        // Mouse olayları
        canvas.addEventListener('mousedown', startDrawing);
        canvas.addEventListener('mousemove', draw);
        canvas.addEventListener('mouseup', stopDrawing);
        canvas.addEventListener('mouseout', stopDrawing);

        // Çizime başlama
        function startDrawing(e) {
            isDrawing = true;
            const rect = canvas.getBoundingClientRect();
            startX = e.clientX - rect.left;
            startY = e.clientY - rect.top;
            lastX = startX;
            lastY = startY;

            // Yazı aracı seçiliyse metin girişi al
            if (currentTool === 'text') {
                textInput = prompt('Yazı girin:', '');
                if (textInput) {
                    drawText(lastX, lastY, textInput, currentColor, currentWidth * 2);

                    // Çizimi kaydet
                    const textDrawing = {
                        type: 'text',
                        x: lastX,
                        y: lastY,
                        text: textInput,
                        color: currentColor,
                        fontSize: currentWidth * 2
                    };

                    allDrawings.push(textDrawing);

                    // Durumu kaydet
                    saveState();
                }
                isDrawing = false;
            }

            // Fırça için nokta dizisi başlat
            if (currentTool === 'brush' || currentTool === 'eraser') {
                currentBrushPoints = [{x: lastX, y: lastY}];
            }
        }

        // Çizim
        function draw(e) {
            if (!isDrawing) return;

            const rect = canvas.getBoundingClientRect();
            const currentX = e.clientX - rect.left;
            const currentY = e.clientY - rect.top;

            if (currentTool === 'brush') {
                // Fırça noktalarını ekle
                currentBrushPoints.push({x: currentX, y: currentY});

                // Fırça çizimi
                ctx.strokeStyle = currentColor;
                ctx.lineWidth = currentWidth;
                ctx.lineJoin = 'round';
                ctx.lineCap = 'round';

                ctx.beginPath();
                ctx.moveTo(lastX, lastY);
                ctx.lineTo(currentX, currentY);
                ctx.stroke();

                lastX = currentX;
                lastY = currentY;
            } else if (currentTool === 'eraser') {
                // Silgi (beyaz fırça)
                ctx.strokeStyle = '#FFFFFF';
                ctx.lineWidth = currentWidth * 2;
                ctx.lineJoin = 'round';
                ctx.lineCap = 'round';

                ctx.beginPath();
                ctx.moveTo(lastX, lastY);
                ctx.lineTo(currentX, currentY);
                ctx.stroke();

                // Silginin noktalarını da kaydet
                currentBrushPoints.push({x: currentX, y: currentY});

                lastX = currentX;
                lastY = currentY;
            }
        }

        // Çizimi durdurma
        function stopDrawing(e) {
            if (!isDrawing) return;

            if (currentTool === 'brush' || currentTool === 'eraser') {
                // Fırça/silgi çizimini kaydet
                const brushDrawing = {
                    type: 'brush',
                    points: currentBrushPoints,
                    color: currentTool === 'brush' ? currentColor : '#FFFFFF',
                    width: currentTool === 'brush' ? currentWidth : currentWidth * 2
                };

                allDrawings.push(brushDrawing);
            } else if (currentTool === 'rect') {
                const rect = canvas.getBoundingClientRect();
                const currentX = e.clientX - rect.left;
                const currentY = e.clientY - rect.top;

                // Dikdörtgen çizimi
                const width = currentX - startX;
                const height = currentY - startY;
                drawRect(startX, startY, width, height, currentColor, currentWidth);

                // Çizimi kaydet
                const rectDrawing = {
                    type: 'rect',
                    x: startX,
                    y: startY,
                    width: width,
                    height: height,
                    color: currentColor,
                    lineWidth: currentWidth
                };

                allDrawings.push(rectDrawing);
            } else if (currentTool === 'circle') {
                const rect = canvas.getBoundingClientRect();
                const currentX = e.clientX - rect.left;
                const currentY = e.clientY - rect.top;

                // Daire çizimi
                const radius = Math.sqrt(Math.pow(currentX - startX, 2) + Math.pow(currentY - startY, 2));
                drawCircle(startX, startY, radius, currentColor, currentWidth);

                // Çizimi kaydet
                const circleDrawing = {
                    type: 'circle',
                    x: startX,
                    y: startY,
                    radius: radius,
                    color: currentColor,
                    lineWidth: currentWidth
                };

                allDrawings.push(circleDrawing);
            }

            // Durumu kaydet
            saveState();

            isDrawing = false;
        }

        // Araç seçimi
        document.querySelectorAll('.tool-button').forEach(button => {
            button.addEventListener('click', function() {
                document.querySelectorAll('.tool-button').forEach(btn => btn.classList.remove('active'));
                this.classList.add('active');
                currentTool = this.dataset.tool;
            });
        });

        // Renk seçimi
        document.querySelector('.color-picker').addEventListener('input', function() {
            currentColor = this.value;
        });

        document.querySelectorAll('[data-color]').forEach(button => {
            button.addEventListener('click', function() {
                currentColor = this.dataset.color;
                document.querySelector('.color-picker').value = currentColor;
            });
        });

        // Çizgi kalınlığı
        document.querySelector('.line-width').addEventListener('input', function() {
            currentWidth = this.value;
            document.getElementById('widthValue').textContent = currentWidth;
        });

        // Canvas temizleme
        document.getElementById('clearCanvas').addEventListener('click', function() {
            if (confirm('Çizim alanını temizlemek istediğinizden emin misiniz?')) {
                ctx.clearRect(0, 0, canvas.width, canvas.height);
                ctx.drawImage(carImage, 0, 0, canvas.width, canvas.height);
                allDrawings = []; // Çizimleri temizle
                saveState();
            }
        });

        // Geri alma
        document.getElementById('undoAction').addEventListener('click', undo);

        // Formu göndermeden önce canvas verilerini kaydet
        form.addEventListener('submit', function() {
            // Canvas verilerini JSON olarak kaydet
            const canvasData = JSON.stringify(allDrawings);
            drawingDataInput.value = canvasData;

            // Eğer "Kaydet ve Testi Tamamla" butonuna tıklandıysa
            if (document.activeElement.name === 'save_kaporta_test' && document.activeElement.value === '1') {
                completeTestInput.value = '1';
            }
        });
    });
</script>
</body>
</html>