<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';
require_once 'classes/MotorTest.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// ID parametresi kontrol
if (!isset($_GET['expertise_id']) || !is_numeric($_GET['expertise_id'])) {
    header("Location: expertises.php");
    exit;
}

$expertiseId = (int)$_GET['expertise_id'];

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $motorTest = new MotorTest($conn);

    // Ekspertiz detaylarını getir
    $expertiseDetails = $expertise->readOne($expertiseId);

    // Ekspertiz bulunamadıysa veya başka şirkete aitse reddet
    if (!$expertiseDetails || $expertiseDetails['company_id'] != $companyId) {
        header("Location: expertises.php");
        exit;
    }

    // Araç bilgilerini getir
    $vehicleDetails = $vehicle->readOne($expertiseDetails['vehicle_id']);

    // Motor testi bilgilerini getir
    $motor_testikayitgetir = $motorTest->readByExpertiseId($expertiseId);

    // Eğer motor testi bilgisi yoksa boş dizi oluştur
    if (!$motor_testikayitgetir) {
        $motor_testikayitgetir = array_fill_keys([
            'atesleme_buji_bobin', 'hava_debi_metre', 'e_kientrik_okuyucu', 'gaz_kelebegi',
            'motor_elektrik_tesisati', 'krank_arka_kece', 'airbeg', 'fren_hidroligi',
            'antifriz', 'otomitik_sanziman_yagi', 'co2_testi', 'aku', 'oksijen_sensoru',
            'motor_yagi', 'lastik_basinc_okuyucu', 'sogutma_fani', 'tum_kayislar',
            'krank_on_kece', 'start_stop', 'hava_filtre_kutu', 'kurbirator_kapak_conta',
            'klima_gazi', 'direksiyon_yagi_ve_pompasi', 'radyator_klima_interkul',
            'turbo', 'sogutma_suyu_hortumu_sizdirmazlik', 'motor_yagi_sizdirmazlik',
            'motor_testi_notlari'
        ], '');
    }
    // Form gönderildiğinde
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Form verilerini al
        $motorTest->expertise_id = $expertiseId;
        $motorTest->vehicle_id = $expertiseDetails['vehicle_id'];
        $motorTest->atesleme_buji_bobin = $_POST['atesleme_buji_bobin'] ?? '';
        $motorTest->hava_debi_metre = $_POST['hava_debi_metre'] ?? '';
        $motorTest->e_kientrik_okuyucu = $_POST['e_kientrik_okuyucu'] ?? '';
        $motorTest->gaz_kelebegi = $_POST['gaz_kelebegi'] ?? '';
        $motorTest->motor_elektrik_tesisati = $_POST['motor_elektrik_tesisati'] ?? '';
        $motorTest->krank_arka_kece = $_POST['krank_arka_kece'] ?? '';
        $motorTest->airbeg = $_POST['airbeg'] ?? '';
        $motorTest->fren_hidroligi = $_POST['fren_hidroligi'] ?? '';
        $motorTest->antifriz = $_POST['antifriz'] ?? '';
        $motorTest->otomitik_sanziman_yagi = $_POST['otomitik_sanziman_yagi'] ?? '';
        $motorTest->co2_testi = $_POST['co2_testi'] ?? '';
        $motorTest->aku = $_POST['aku'] ?? '';
        $motorTest->oksijen_sensoru = $_POST['oksijen_sensoru'] ?? '';
        $motorTest->motor_yagi = $_POST['motor_yagi'] ?? '';
        $motorTest->lastik_basinc_okuyucu = $_POST['lastik_basinc_okuyucu'] ?? '';
        $motorTest->sogutma_fani = $_POST['sogutma_fani'] ?? '';
        $motorTest->tum_kayislar = $_POST['tum_kayislar'] ?? '';
        $motorTest->krank_on_kece = $_POST['krank_on_kece'] ?? '';
        $motorTest->start_stop = $_POST['start_stop'] ?? '';
        $motorTest->hava_filtre_kutu = $_POST['hava_filtre_kutu'] ?? '';
        $motorTest->kurbirator_kapak_conta = $_POST['kurbirator_kapak_conta'] ?? '';
        $motorTest->klima_gazi = $_POST['klima_gazi'] ?? '';
        $motorTest->direksiyon_yagi_ve_pompasi = $_POST['direksiyon_yagi_ve_pompasi'] ?? '';
        $motorTest->radyator_klima_interkul = $_POST['radyator_klima_interkul'] ?? '';
        $motorTest->turbo = $_POST['turbo'] ?? '';
        $motorTest->sogutma_suyu_hortumu_sizdirmazlik = $_POST['sogutma_suyu_hortumu_sizdirmazlik'] ?? '';
        $motorTest->motor_yagi_sizdirmazlik = $_POST['motor_yagi_sizdirmazlik'] ?? '';
        $motorTest->motor_testi_notlari = $_POST['motor_testi_notlari'] ?? '';

        // Verileri kaydet
        if ($motorTest->saveOrUpdate()) {
            // Ekspertiz durumunu güncelle
            // POST işlemi - Test tamamlama
            if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                if (isset($_POST['complete_test']) && isset($_POST['test_type'])) {
                    $testType = $_POST['test_type'];

                    // Mevcut testleri güncelle
                    $tests[$testType] = 2; // 2 = Tamamlandı

                    // Extra data'yı güncelle
                    $extraData['tests'] = $tests;
                    $expertise->extra_data = json_encode($extraData);
                    $expertise->id = $expertiseId;

                    if ($expertise->updateExtraData()) {
                        $successMessage = str_replace("_", " ", ucfirst($testType)) . " başarıyla tamamlandı.";

                        // Sayfayı yenile (PRG pattern)
                        header("Location: expertise_form.php?id=" . $expertiseId . "&success=" . urlencode($successMessage));
                        exit;
                    } else {
                        $errorMessage = "Test durumu güncellenirken bir hata oluştu.";
                    }
                }
            }

            $successMessage = "Motor testi başarıyla kaydedildi.";

            // Sayfayı yenile
            header("Location: motor_test.php?expertise_id=" . $expertiseId . "&success=" . urlencode($successMessage));
            exit;
        } else {
            $errorMessage = "Motor testi kaydedilirken bir hata oluştu.";
        }
    }

    // Success mesajı
    if (isset($_GET['success'])) {
        $successMessage = $_GET['success'];
    }

    // Sayfa başlığı
    $pageTitle = "Motor Testi - " . $expertiseDetails['expertise_code'];

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}

// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - Araç Ekspertiz Sistemi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <!-- Toastr Bildirimler için -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.css">
    <!-- Custom CSS -->
    <link rel="stylesheet" href="assets/css/style.css">

    <?php include "includes/style.php"; ?>
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --success-color: #4cc9f0;
            --warning-color: #f72585;
            --danger-color: #e63946;
            --dark-color: #212529;
            --light-color: #f8f9fa;
        }

        .form-group {
            margin-bottom: 1.5rem;
        }

        .form-label {
            font-weight: 500;
            margin-bottom: 0.5rem;
            color: #495057;
        }

        .grid-title {
            margin-bottom: 1.5rem;
            padding-bottom: 0.75rem;
            border-bottom: 1px solid #e9ecef;
        }

        .grid-title h4 {
            font-weight: 600;
            color: #212529;
            margin-bottom: 0;
        }

        .grid-title .semi-bold {
            font-weight: 500;
            color: #6c757d;
        }

        select, textarea {
            border: 1px solid #ced4da;
            padding: 0.375rem 0.75rem;
            border-radius: 0.25rem;
            transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
            width: 100%;
        }

        select:focus, textarea:focus {
            border-color: #80bdff;
            outline: 0;
            box-shadow: 0 0 0 0.25rem rgba(13, 110, 253, 0.25);
        }

        textarea {
            min-height: 120px;
        }

        .sticky-buttons {
            position: sticky;
            bottom: 0;
            background-color: #fff;
            padding: 1rem 0;
            box-shadow: 0 -4px 6px -1px rgba(0, 0, 0, 0.1);
            z-index: 1000;
            border-top: 1px solid #e9ecef;
        }
    </style>
</head>
<body>
<!-- Sidebar -->
<?php include 'includes/sidebar.php'; ?>

<!-- Main Content -->
<div class="main-content">
    <!-- Topbar -->
    <?php include 'includes/topbar.php'; ?>

    <!-- Content -->
    <div class="content">
        <!-- Page Header -->
        <div class="page-header d-flex justify-content-between align-items-center">
            <div>
                <h1 class="page-title">Motor Testi</h1>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="dashboard.php">Ana Sayfa</a></li>
                        <li class="breadcrumb-item"><a href="expertises.php">Ekspertizler</a></li>
                        <li class="breadcrumb-item"><a href="expertise_form.php?id=<?php echo $expertiseId; ?>"><?php echo htmlspecialchars($expertiseDetails['expertise_code']); ?></a></li>
                        <li class="breadcrumb-item active" aria-current="page">Motor Testi</li>
                    </ol>
                </nav>
            </div>
            <div>
                <a href="expertise_form.php?id=<?php echo $expertiseId; ?>" class="btn btn-secondary">
                    <i class="fas fa-arrow-left me-2"></i> Geri Dön
                </a>
            </div>
        </div>

        <?php if (isset($errorMessage)): ?>
            <div class="alert alert-danger" role="alert">
                <i class="fas fa-exclamation-circle me-2"></i> <?php echo $errorMessage; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($successMessage)): ?>
            <div class="alert alert-success" role="alert">
                <i class="fas fa-check-circle me-2"></i> <?php echo $successMessage; ?>
            </div>
        <?php endif; ?>

        <!-- Araç Bilgileri Özeti -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title mb-0"><i class="fas fa-car me-2"></i> Araç Bilgileri</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-">
                        <p class="mb-1"><strong>Plaka:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['plate_number']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Marka/Model:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['brand_name'] . ' ' . $vehicleDetails['model_name']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Yıl:</strong></p>
                        <p><?php echo htmlspecialchars($vehicleDetails['year']); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p class="mb-1"><strong>Ekspertiz Kodu:</strong></p>
                        <p><?php echo htmlspecialchars($expertiseDetails['expertise_code']); ?></p>
                    </div>
                </div>
            </div>
        </div>
        <!-- Motor Testi Formu -->
        <div class="card">
            <div class="card-header">
                <h5 class="card-title mb-0"><i class="fas fa-cogs me-2"></i> Motor Testi Formu</h5>
            </div>
            <div class="card-body">
                <form action="" method="POST">
                    <div class="grid-title no-border">
                        <h4>Motor <span class="semi-bold">Test Sonuçları</span></h4>
                    </div>

                    <div class="row">
                        <div class="col-md-6">

                            <div class="form-group">
                                <label class="form-label">ATEŞLEME BUJİ BOBİN: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="atesleme_buji_bobin">
                                        <option <?php if($motor_testikayitgetir["atesleme_buji_bobin"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["atesleme_buji_bobin"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["atesleme_buji_bobin"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["atesleme_buji_bobin"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">HAVA DEBİ METRE:  </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="hava_debi_metre">
                                        <option <?php if($motor_testikayitgetir["hava_debi_metre"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["hava_debi_metre"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["hava_debi_metre"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["hava_debi_metre"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">E KİENTRİK OKUYUCU: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="e_kientrik_okuyucu">
                                        <option  <?php if($motor_testikayitgetir["e_kientrik_okuyucu"]==""){ echo "selected"; } ?> value=""></option>
                                        <option  <?php if($motor_testikayitgetir["e_kientrik_okuyucu"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["e_kientrik_okuyucu"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["e_kientrik_okuyucu"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">GAZ KELEBEĞİ :</label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="gaz_kelebegi">
                                        <option <?php if($motor_testikayitgetir["gaz_kelebegi"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["gaz_kelebegi"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["gaz_kelebegi"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["gaz_kelebegi"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">MOTOR ELEKTRİK TESİSATI:  </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="motor_elektrik_tesisati">
                                        <option <?php if($motor_testikayitgetir["motor_elektrik_tesisati"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["motor_elektrik_tesisati"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["motor_elektrik_tesisati"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["motor_elektrik_tesisati"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">KRANK ARKA KEÇE: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="krank_arka_kece">
                                        <option <?php if($motor_testikayitgetir["krank_arka_kece"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["krank_arka_kece"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["krank_arka_kece"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["krank_arka_kece"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="form-label">AİRBEG:  </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="airbeg">
                                        <option  <?php if($motor_testikayitgetir["airbeg"]==""){ echo "selected"; } ?> value=""></option>
                                        <option  <?php if($motor_testikayitgetir["airbeg"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["airbeg"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["airbeg"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">FREN HİDROLİĞİ: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="fren_hidroligi">
                                        <option <?php if($motor_testikayitgetir["fren_hidroligi"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["fren_hidroligi"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["fren_hidroligi"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["fren_hidroligi"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">ANTİFRİZ: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="antifriz">
                                        <option <?php if($motor_testikayitgetir["antifriz"]==""){ echo "selected"; } ?>   value=""></option>
                                        <option <?php if($motor_testikayitgetir["antifriz"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["antifriz"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["antifriz"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">OTOMİTİK ŞANZIMAN YAĞI: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="otomitik_sanziman_yagi">
                                        <option <?php if($motor_testikayitgetir["otomitik_sanziman_yagi"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["otomitik_sanziman_yagi"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["otomitik_sanziman_yagi"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["otomitik_sanziman_yagi"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">CO2 Testi: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="co2_testi">
                                        <option <?php if($motor_testikayitgetir["co2_testi"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["co2_testi"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["co2_testi"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["co2_testi"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">AKÜ: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="aku">
                                        <option <?php if($motor_testikayitgetir["aku"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["aku"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["aku"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["aku"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">OKSİJEN SENSÖRÜ: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="oksijen_sensoru">
                                        <option <?php if($motor_testikayitgetir["oksijen_sensoru"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["oksijen_sensoru"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["oksijen_sensoru"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["oksijen_sensoru"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>



                            <div class="form-group">
                                <label class="form-label">MOTOR YAĞI: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="motor_yagi">
                                        <option <?php if($motor_testikayitgetir["motor_yagi"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["motor_yagi"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["motor_yagi"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["motor_yagi"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>
                            <!-- Diğer sol kolon form alanları buraya gelecek -->
                            <!-- İlk 15 select form alanı burada olacak -->
                        </div>
                        <div class="col-md-6">

                            <div class="form-group">
                                <label class="form-label">LASTİK BASINÇ OKUYUCU: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="lastik_basinc_okuyucu">
                                        <option <?php if($motor_testikayitgetir["lastik_basinc_okuyucu"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["lastik_basinc_okuyucu"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["lastik_basinc_okuyucu"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["lastik_basinc_okuyucu"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">SOĞUTMA FANI: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="sogutma_fani">
                                        <option <?php if($motor_testikayitgetir["sogutma_fani"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option <?php if($motor_testikayitgetir["sogutma_fani"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["sogutma_fani"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["sogutma_fani"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">TÜM KAYIŞLAR: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="tum_kayislar">
                                        <option <?php if($motor_testikayitgetir["tum_kayislar"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["tum_kayislar"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["tum_kayislar"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["tum_kayislar"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>



                            <div class="form-group">
                                <label class="form-label">KRANK ÖN KEÇE: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="krank_on_kece">
                                        <option <?php if($motor_testikayitgetir["krank_on_kece"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["krank_on_kece"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["krank_on_kece"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["krank_on_kece"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">START STOP: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="start_stop">
                                        <option  <?php if($motor_testikayitgetir["start_stop"]==""){ echo "selected"; } ?> value=""></option>
                                        <option  <?php if($motor_testikayitgetir["start_stop"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["start_stop"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["start_stop"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">HAVA FİLTRE KUTU: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="hava_filtre_kutu">
                                        <option <?php if($motor_testikayitgetir["hava_filtre_kutu"]==""){ echo "selected"; } ?>   value=""></option>
                                        <option <?php if($motor_testikayitgetir["hava_filtre_kutu"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["hava_filtre_kutu"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["hava_filtre_kutu"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">KÜRBİRATÖR KAPAK CONTA: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="kurbirator_kapak_conta">
                                        <option <?php if($motor_testikayitgetir["kurbirator_kapak_conta"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["kurbirator_kapak_conta"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["kurbirator_kapak_conta"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["kurbirator_kapak_conta"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">KLİMA GAZI </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="klima_gazi">
                                        <option <?php if($motor_testikayitgetir["klima_gazi"]==""){ echo "selected"; } ?> value=""></option>
                                        <option <?php if($motor_testikayitgetir["klima_gazi"]=="İYİ"){ echo "selected"; } ?> value="İYİ">İYİ</option>
                                        <option <?php if($motor_testikayitgetir["klima_gazi"]=="ORTA"){ echo "selected"; } ?> value="ORTA">ORTA</option>
                                        <option <?php if($motor_testikayitgetir["klima_gazi"]=="KÖTÜ"){ echo "selected"; } ?> value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">DİREKSİYON YAĞI VE POMPASI: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="direksiyon_yagi_ve_pompasi">
                                        <option  <?php if($motor_testikayitgetir["direksiyon_yagi_ve_pompasi"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option  <?php if($motor_testikayitgetir["direksiyon_yagi_ve_pompasi"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["direksiyon_yagi_ve_pompasi"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["direksiyon_yagi_ve_pompasi"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">RADYATÖR KLİMA İNTERKUL: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="radyator_klima_interkul">
                                        <option  <?php if($motor_testikayitgetir["radyator_klima_interkul"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option  <?php if($motor_testikayitgetir["radyator_klima_interkul"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["radyator_klima_interkul"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["radyator_klima_interkul"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">TURBO: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="turbo">
                                        <option  <?php if($motor_testikayitgetir["turbo"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option  <?php if($motor_testikayitgetir["turbo"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["turbo"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["turbo"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                            <div class="form-group">
                                <label class="form-label">SOĞUTMA SUYU HORTUMU SIZDIRMAZLIK: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="sogutma_suyu_hortumu_sizdirmazlik">
                                        <option  <?php if($motor_testikayitgetir["sogutma_suyu_hortumu_sizdirmazlik"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option  <?php if($motor_testikayitgetir["sogutma_suyu_hortumu_sizdirmazlik"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["sogutma_suyu_hortumu_sizdirmazlik"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["sogutma_suyu_hortumu_sizdirmazlik"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>


                            <div class="form-group">
                                <label class="form-label">MOTOR YAĞI SIZDIRMAZLIK: </label>
                                <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                    <select name="motor_yagi_sizdirmazlik">
                                        <option  <?php if($motor_testikayitgetir["motor_yagi_sizdirmazlik"]==""){ echo "selected"; } ?>  value=""></option>
                                        <option  <?php if($motor_testikayitgetir["motor_yagi_sizdirmazlik"]=="İYİ"){ echo "selected"; } ?>  value="İYİ">İYİ</option>
                                        <option  <?php if($motor_testikayitgetir["motor_yagi_sizdirmazlik"]=="ORTA"){ echo "selected"; } ?>  value="ORTA">ORTA</option>
                                        <option  <?php if($motor_testikayitgetir["motor_yagi_sizdirmazlik"]=="KÖTÜ"){ echo "selected"; } ?>  value="KÖTÜ">KÖTÜ</option>
                                    </select>
                                </div>
                            </div>

                        </div>
                        <div class="grid-title no-border">
                            <h4>Motor Testi  <span class="semi-bold"> NOTLARI</span></h4>
                        </div>

                        <div class="form-group">
                            <label class="form-label">Notlar : </label>
                            <div class="controls" style=" margin-top: 0; margin-left: 0; ">
                                <textarea rows="6" cols="50" name="motor_testi_notlari"><?php echo $motor_testikayitgetir["motor_testi_notlari"]; ?></textarea>
                            </div>
                        </div>

                        <!-- Kaydet ve Testi Tamamla Butonları -->
                        <div class="sticky-buttons">
                            <div class="row">
                                <div class="col-md-6">
                                    <button type="submit" class="btn btn-primary w-100" name="save">
                                        <i class="fas fa-save me-2"></i> Kaydet
                                    </button>
                                </div>
                                <div class="col-md-6">
                                    <button type="submit" class="btn btn-success w-100" name="complete_test" value="1">
                                        <i class="fas fa-check-circle me-2"></i> Kaydet ve Testi Tamamla
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
<!-- Bootstrap JS with Popper -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Toastr JS -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/toastr.min.js"></script>

<!-- Custom JS -->
<script>
    // Toastr bildirim ayarları
    toastr.options = {
        "closeButton": true,
        "progressBar": true,
        "positionClass": "toast-top-right",
        "timeOut": "3000"
    };

    // Sidebar Toggle - sidebar.php içerisinde tanımlı elemanlar için
    $(document).ready(function() {
        if (document.getElementById('toggle-sidebar')) {
            document.getElementById('toggle-sidebar').addEventListener('click', function() {
                document.querySelector('.sidebar').classList.toggle('show');
            });
        }

        if (document.getElementById('sidebar-toggle')) {
            document.getElementById('sidebar-toggle').addEventListener('click', function() {
                document.querySelector('.sidebar').classList.remove('show');
            });
        }
    });
</script>
</body>
</html>