<?php
// Oturum başlatma
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    // Kullanıcı giriş yapmamışsa login sayfasına yönlendir
    header("Location: login.php");
    exit;
}

// Veritabanı bağlantısı ve sınıfları dahil etme
require_once 'config/database.php';
require_once 'classes/User.php';
require_once 'classes/Expertise.php';
require_once 'classes/Vehicle.php';
require_once 'classes/Customer.php';
require_once 'classes/Template.php';

// Kullanıcı bilgilerini alma
$userId = $_SESSION['user_id'];
$username = $_SESSION['username'];
$userRole = $_SESSION['user_role'];
$companyId = $_SESSION['company_id'];

// Tarih formatı ayarları
setlocale(LC_TIME, 'tr_TR.UTF-8', 'tr_TR', 'tr', 'turkish');
date_default_timezone_set('Europe/Istanbul');

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Sınıf nesnelerini oluşturma
    $expertise = new Expertise($conn);
    $vehicle = new Vehicle($conn);
    $customer = new Customer($conn);
    $template = new Template($conn);
    $user = new User($conn);

    // Kullanıcıyı getir (eksper olarak)
    $user->readOne($userId);

    // Tüm müşterileri getir
    $customers = $customer->getCustomers($companyId, 100, 0); // İlk 100 müşteri

    // Tüm ekspertiz şablonlarını getir
    $templates = $template->getTemplates($companyId);

    // Form gönderildiğinde
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Formdaki verileri al
        $customerId = (int)$_POST['customer_id'] ?? 0;
        $vehicleId = (int)$_POST['vehicle_id'] ?? 0;
        $templateId = (int)$_POST['template_id'] ?? 0;
        $expertiseDate = $_POST['expertise_date'] ?? date('Y-m-d H:i:s');
        $location = $_POST['location'] ?? '';
        $notes = $_POST['notes'] ?? '';

        // Veri doğrulama
        $errors = [];

        if ($customerId <= 0) {
            $errors[] = "Müşteri seçimi zorunludur.";
        }

        if ($vehicleId <= 0) {
            $errors[] = "Araç seçimi zorunludur.";
        }

        if ($templateId <= 0) {
            $errors[] = "Ekspertiz şablonu seçimi zorunludur.";
        }

        if (empty($expertiseDate)) {
            $errors[] = "Ekspertiz tarihi zorunludur.";
        }

        // Hata yoksa ekspertiz oluştur
        if (empty($errors)) {
            // Ekspertiz kodu oluştur
            $expertiseCode = $expertise->generateExpertiseCode($companyId);

            // Ekspertiz özelliklerini ayarla
            $expertise->company_id = $companyId;
            $expertise->vehicle_id = $vehicleId;
            $expertise->customer_id = $customerId;
            $expertise->expert_id = $userId;
            $expertise->template_id = $templateId;
            $expertise->expertise_code = $expertiseCode;
            $expertise->expertise_date = $expertiseDate;
            $expertise->status = 'pending';
            $expertise->total_score = 0; // Başlangıçta puan yok
            $expertise->notes = $notes;
            $expertise->location = $location;
            $expertise->report_url = ''; // Henüz rapor yok

            // Ekspertizi oluştur
            if ($expertise->create()) {
                // Başarılı mesajı
                $successMessage = "Ekspertiz başarıyla oluşturuldu. Kod: " . $expertiseCode;

                // Ekspertiz formuna yönlendir
                header("Location: expertise_form.php?id=" . $expertise->id);
                exit;
            } else {
                // Hata mesajı
                $errorMessage = "Ekspertiz oluşturulurken bir hata oluştu.";
            }
        } else {
            // Hata mesajlarını birleştir
            $errorMessage = implode("<br>", $errors);
        }
    }

    // Sayfa başlığı
    $pageTitle = "Yeni Ekspertiz";

} catch (Exception $e) {
    // Hata durumunda
    $errorMessage = "Sistem hatası: " . $e->getMessage();
}

// Aktif sayfa
$activePage = 'expertises';
?>
<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Araç Bilgileri Formu</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Select2 -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" />
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --success-color: #4cc9f0;
            --light-color: #f8f9fa;
        }

        body {
            font-family: 'Arial', sans-serif;
            background-color: #f9fafb;
        }

        .card {
            border-radius: 8px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
        }

        .card-header {
            background-color: var(--light-color);
            border-bottom: 1px solid #eee;
            font-weight: 600;
        }

        .form-label {
            font-weight: 500;
            font-size: 0.9rem;
        }

        .vehicle-type-item {
            border: 2px solid #ddd;
            border-radius: 8px;
            padding: 10px;
            margin-bottom: 15px;
            cursor: pointer;
            transition: all 0.3s;
        }

        .vehicle-type-item:hover {
            border-color: var(--primary-color);
        }

        .vehicle-type-item.selected {
            border-color: var(--primary-color);
            background-color: rgba(67, 97, 238, 0.05);
        }

        .vehicle-type-item img {
            max-width: 100%;
            height: auto;
        }

        .required-field::after {
            content: "*";
            color: red;
            margin-left: 4px;
        }
    </style>
</head>
<body>
<div class="container-fluid py-4">
    <div class="row">
        <div class="col-12 mb-4">
            <h3 class="mb-3">Araç Bilgileri Formu</h3>

            <form id="vehicleForm" method="post" action="">
                <div class="row">
                    <!-- Sol Kolon - Araç Detayları -->
                    <div class="col-md-6">
                        <div class="card">
                            <div class="card-header">
                                Araç Bilgileri
                            </div>
                            <div class="card-body">
                                <div class="mb-3">
                                    <label for="plate_number" class="form-label required-field">Plaka</label>
                                    <input type="text" class="form-control" id="plate_number" name="plate_number" required>
                                </div>

                                <div class="mb-3">
                                    <label for="vin_number" class="form-label">Şasi No</label>
                                    <input type="text" class="form-control" id="vin_number" name="vin_number">
                                    <div class="form-text text-muted">Maximum 17 karakter</div>
                                </div>

                                <div class="mb-3">
                                    <label for="brand_id" class="form-label required-field">Marka</label>
                                    <select class="form-select" id="brand_id" name="brand_id" required>
                                        <option value="">Marka Seçin</option>
                                        <option value="1">Audi</option>
                                        <option value="2">BMW</option>
                                        <option value="3">Mercedes</option>
                                        <option value="4">Volkswagen</option>
                                        <option value="5">Ford</option>
                                        <option value="6">Renault</option>
                                        <option value="7">Toyota</option>
                                        <option value="8">Honda</option>
                                        <option value="9">Hyundai</option>
                                        <!-- Diğer markalar buraya eklenebilir -->
                                    </select>
                                </div>

                                <div class="mb-3">
                                    <label for="model_id" class="form-label required-field">Model</label>
                                    <select class="form-select" id="model_id" name="model_id" required disabled>
                                        <option value="">Önce Marka Seçin</option>
                                    </select>
                                </div>

                                <div class="mb-3">
                                    <label for="year" class="form-label required-field">Model Yılı</label>
                                    <input type="number" class="form-control" id="year" name="year" min="1900" max="<?php echo date('Y'); ?>" required>
                                </div>

                                <div class="mb-3">
                                    <label for="fuel_type" class="form-label">Yakıt Cinsi</label>
                                    <select class="form-select" id="fuel_type" name="fuel_type">
                                        <option value="">Seçiniz</option>
                                        <option value="Benzin">Benzin</option>
                                        <option value="Dizel">Dizel</option>
                                        <option value="LPG">LPG</option>
                                        <option value="Elektrik">Elektrik</option>
                                        <option value="Hibrit">Hibrit</option>
                                    </select>
                                </div>

                                <div class="mb-3">
                                    <label for="color" class="form-label">Renk</label>
                                    <input type="text" class="form-control" id="color" name="color">
                                </div>

                                <div class="mb-3">
                                    <label for="engine_power" class="form-label">Ruhsat Gücü</label>
                                    <input type="text" class="form-control" id="engine_power" name="engine_power" placeholder="Örn: 110 HP">
                                </div>

                                <div class="mb-3">
                                    <label for="engine_modifications" class="form-label">Motor Yapılan</label>
                                    <textarea class="form-control" id="engine_modifications" name="engine_modifications" rows="2"></textarea>
                                </div>

                                <div class="mb-3">
                                    <label for="mileage" class="form-label">Araç KM</label>
                                    <input type="number" class="form-control" id="mileage" name="mileage" min="0">
                                </div>

                                <div class="mb-3">
                                    <label for="vehicle_type" class="form-label">Araç Tipi</label>
                                    <input type="hidden" id="vehicle_type" name="vehicle_type" value="">
                                    <div class="row">
                                        <?php
                                        // 9 farklı araç tipi için resimler
                                        $vehicleTypes = [
                                            1 => 'Sedan',
                                            2 => 'Hatchback',
                                            3 => 'SUV',
                                            4 => 'Crossover',
                                            5 => 'Minivan',
                                            6 => 'Pickup',
                                            7 => 'Coupe',
                                            8 => 'Convertible',
                                            9 => 'Station Wagon'
                                        ];

                                        foreach ($vehicleTypes as $id => $name):
                                            ?>
                                            <div class="col-md-4 col-sm-6">
                                                <div class="vehicle-type-item" data-vehicle-type="<?php echo $id; ?>">
                                                    <img src="assets/images/vehicles/vehicle_type_<?php echo $id; ?>.png" alt="<?php echo $name; ?>" class="img-fluid">
                                                    <div class="text-center mt-2"><?php echo $name; ?></div>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Sağ Kolon - Müşteri ve Test Bilgileri -->
                    <div class="col-md-6">
                        <div class="card">
                            <div class="card-header">
                                Müşteri Bilgileri
                            </div>
                            <div class="card-body">
                                <div class="mb-3">
                                    <label for="customer_name" class="form-label required-field">Adı & Soyadı</label>
                                    <input type="text" class="form-control" id="customer_name" name="customer_name" required>
                                </div>

                                <div class="mb-3">
                                    <label for="customer_phone" class="form-label required-field">Telefon</label>
                                    <input type="tel" class="form-control" id="customer_phone" name="customer_phone" required>
                                </div>

                                <div class="mb-3">
                                    <label for="products" class="form-label">Araçtaki Ürünler</label>
                                    <textarea class="form-control" id="products" name="products" rows="2"></textarea>
                                </div>
                            </div>
                        </div>

                        <div class="card mt-4">
                            <div class="card-header">
                                Satıcı Bilgileri
                            </div>
                            <div class="card-body">
                                <div class="mb-3">
                                    <label for="seller_name" class="form-label required-field">Adı & Soyadı</label>
                                    <input type="text" class="form-control" id="seller_name" name="seller_name" required>
                                </div>

                                <div class="mb-3">
                                    <label for="seller_phone" class="form-label required-field">Telefon</label>
                                    <input type="tel" class="form-control" id="seller_phone" name="seller_phone" required>
                                </div>
                            </div>
                        </div>

                        <div class="card mt-4">
                            <div class="card-header">
                                Yapılacak Testler
                            </div>
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_kaportaci" name="tests[]" value="kaportaci">
                                            <label class="form-check-label" for="test_kaportaci">
                                                Kaportacı Test
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_motor" name="tests[]" value="motor">
                                            <label class="form-check-label" for="test_motor">
                                                Motor Test
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_co2" name="tests[]" value="co2">
                                            <label class="form-check-label" for="test_co2">
                                                CO2 Test
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_sot" name="tests[]" value="sot">
                                            <label class="form-check-label" for="test_sot">
                                                SOT Test
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_mekanik" name="tests[]" value="mekanik">
                                            <label class="form-check-label" for="test_mekanik">
                                                Mekanik Test
                                            </label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_arac" name="tests[]" value="arac">
                                            <label class="form-check-label" for="test_arac">
                                                Araç Testi
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_suspansiyon" name="tests[]" value="suspansiyon">
                                            <label class="form-check-label" for="test_suspansiyon">
                                                Süspansiyon
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_motor_perf" name="tests[]" value="motor_perf">
                                            <label class="form-check-label" for="test_motor_perf">
                                                Motor Performans
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_mekanik2" name="tests[]" value="mekanik2">
                                            <label class="form-check-label" for="test_mekanik2">
                                                Mekanik Test 2
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_beyin" name="tests[]" value="beyin">
                                            <label class="form-check-label" for="test_beyin">
                                                Beyin Test
                                            </label>
                                        </div>
                                        <div class="form-check mb-2">
                                            <input class="form-check-input" type="checkbox" id="test_101" name="tests[]" value="101">
                                            <label class="form-check-label" for="test_101">
                                                101 Test
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="row mt-4">
                    <div class="col-12 text-end">
                        <button type="button" class="btn btn-secondary me-2">İptal</button>
                        <button type="submit" class="btn btn-primary">Kaydet</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Select2 -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<script>
    $(document).ready(function() {
        // Select2 başlatma
        $('#brand_id, #model_id, #fuel_type').select2({
            theme: 'bootstrap-5',
            width: '100%'
        });

        // Marka değiştiğinde modelleri getir
        $('#brand_id').on('change', function() {
            const brandId = $(this).val();
            const modelSelect = $('#model_id');

            if (brandId) {
                // Modelleri getir (Gerçek uygulamada AJAX ile)
                modelSelect.prop('disabled', false);

                // Demo amaçlı örnek modeller
                modelSelect.empty().append('<option value="">Model Seçin</option>');

                // Her marka için örnek modeller
                const demoModels = {
                    '1': [
                        {id: 1, name: 'A3'},
                        {id: 2, name: 'A4'},
                        {id: 3, name: 'A6'},
                        {id: 4, name: 'Q5'}
                    ],
                    '2': [
                        {id: 5, name: '3 Serisi'},
                        {id: 6, name: '5 Serisi'},
                        {id: 7, name: 'X3'},
                        {id: 8, name: 'X5'}
                    ],
                    '3': [
                        {id: 9, name: 'C Serisi'},
                        {id: 10, name: 'E Serisi'},
                        {id: 11, name: 'GLC'},
                        {id: 12, name: 'S Serisi'}
                    ],
                    '4': [
                        {id: 13, name: 'Golf'},
                        {id: 14, name: 'Passat'},
                        {id: 15, name: 'Tiguan'},
                        {id: 16, name: 'Polo'}
                    ],
                    '5': [
                        {id: 17, name: 'Focus'},
                        {id: 18, name: 'Mondeo'},
                        {id: 19, name: 'Kuga'},
                        {id: 20, name: 'Fiesta'}
                    ]
                };

                // Seçilen markaya ait modelleri ekle
                if (demoModels[brandId]) {
                    demoModels[brandId].forEach(function(model) {
                        modelSelect.append(new Option(model.name, model.id));
                    });
                }
            } else {
                modelSelect.prop('disabled', true);
                modelSelect.empty().append('<option value="">Önce Marka Seçin</option>');
            }
        });

        // Araç tipi seçimi
        $('.vehicle-type-item').on('click', function() {
            $('.vehicle-type-item').removeClass('selected');
            $(this).addClass('selected');

            const vehicleType = $(this).data('vehicle-type');
            $('#vehicle_type').val(vehicleType);
        });
    });
</script>
</body>
</html>